@@ -12,7 +12,6 @@
 Helper functions to handle SQL lineage operations
 """
 import traceback
-from logging.config import DictConfigurator
 from typing import Any, Iterable, Iterator, List, Optional
 
 from metadata.generated.schema.api.lineage.addLineage import AddLineageRequest
@@ -23,9 +22,10 @@ from metadata.generated.schema.type.entityLineage import (
     LineageDetails,
 )
 from metadata.generated.schema.type.entityReference import EntityReference
+from metadata.ingestion.lineage.parser import LineageParser
 from metadata.ingestion.ometa.ometa_api import OpenMetadata
 from metadata.utils import fqn
-from metadata.utils.helpers import insensitive_replace
+from metadata.utils.fqn import build_es_fqn_search_string
 from metadata.utils.logger import utils_logger
 from metadata.utils.lru_cache import LRUCache
 
@@ -33,40 +33,18 @@ logger = utils_logger()
 LRU_CACHE_SIZE = 4096
 
 
-def clean_raw_query(raw_query: str) -> str:
-    """
-    Given a raw query from any input (e.g., view definition,
-    query from logs, etc.), perform a cleaning step
-    before passing it to the LineageRunner
-    """
-    clean_query = insensitive_replace(
-        raw_str=raw_query,
-        to_replace=" copy grants ",  # snowflake specific
-        replace_by=" ",  # remove it as it does not add any value to lineage
-    )
-
-    return clean_query
-
-
-def split_raw_table_name(database: str, raw_name: str) -> dict:
-    database_schema = None
-    if "." in raw_name:
-        database_schema, table = fqn.split(raw_name)[-2:]
-        if database_schema == "<default>":
-            database_schema = None
-    return {"database": database, "database_schema": database_schema, "table": table}
-
-
 def get_column_fqn(table_entity: Table, column: str) -> Optional[str]:
     """
     Get fqn of column if exist in table entity
     """
     if not table_entity:
-        return
+        return None
     for tbl_column in table_entity.columns:
         if column.lower() == tbl_column.name.__root__.lower():
             return tbl_column.fullyQualifiedName.__root__
 
+    return None
+
 
 search_cache = LRUCache(LRU_CACHE_SIZE)
 
@@ -86,8 +64,20 @@ def search_table_entities(
     search_tuple = (service_name, database, database_schema, table)
     if search_tuple in search_cache:
         return search_cache.get(search_tuple)
-    else:
-        try:
+    try:
+        table_entities: Optional[List[Table]] = []
+        # search on ES first
+        fqn_search_string = build_es_fqn_search_string(
+            database, database_schema, service_name, table
+        )
+        es_result_entities = metadata.es_search_from_fqn(
+            entity_type=Table,
+            fqn_search_string=fqn_search_string,
+        )
+        if es_result_entities:
+            table_entities = es_result_entities
+        else:
+            # build fqns without searching on ES
             table_fqns = fqn.build(
                 metadata,
                 entity_type=Table,
@@ -96,19 +86,20 @@ def search_table_entities(
                 schema_name=database_schema,
                 table_name=table,
                 fetch_multiple_entities=True,
+                skip_es_search=True,
             )
-            table_entities: Optional[List[Table]] = []
             for table_fqn in table_fqns or []:
                 table_entity: Table = metadata.get_by_name(Table, fqn=table_fqn)
                 if table_entity:
                     table_entities.append(table_entity)
-            search_cache.put(search_tuple, table_entities)
-            return table_entities
-        except Exception as exc:
-            logger.debug(traceback.format_exc())
-            logger.error(
-                f"Error searching for table entities for service [{service_name}]: {exc}"
-            )
+        search_cache.put(search_tuple, table_entities)
+        return table_entities
+    except Exception as exc:
+        logger.debug(traceback.format_exc())
+        logger.error(
+            f"Error searching for table entities for service [{service_name}]: {exc}"
+        )
+        return None
 
 
 def get_table_entities_from_query(
@@ -117,7 +108,7 @@ def get_table_entities_from_query(
     database_name: str,
     database_schema: str,
     table_name: str,
-) -> List[Table]:
+) -> Optional[List[Table]]:
     """
     Fetch data from API and ES with a fallback strategy.
 
@@ -131,9 +122,8 @@ def get_table_entities_from_query(
     :return: List of tables matching the criteria
     """
 
-    # First try to find the data from the given db and schema
-    # Otherwise, pick it up from the table_name str
-    # Finally, try with upper case
+    # First try to find the data from the given db and schema (with table name as given or uppercase)
+    # Otherwise, pick it up from the table_name str (with table name as given or uppercase)
 
     split_table = table_name.split(".")
     empty_list: List[Any] = [None]  # Otherwise, there's a typing error in the concat
@@ -164,6 +154,8 @@ def get_table_entities_from_query(
     if table_entities:
         return table_entities
 
+    return None
+
 
 def get_column_lineage(
     to_entity: Table,
@@ -172,6 +164,18 @@ def get_column_lineage(
     from_table_raw_name: str,
     column_lineage_map: dict,
 ) -> List[ColumnLineage]:
+    """Get column lineage
+
+    Args:
+        to_entity (Table): entity to link to
+        from_entity (Table): entity link comes from
+        to_table_raw_name (str): table entity raw name we link to
+        from_table_raw_name (str): table entity raw name we link from
+        column_lineage_map (dict): map of the column lineage
+
+    Returns:
+        List[ColumnLineage]
+    """
     column_lineage = []
     if column_lineage_map.get(to_table_raw_name) and column_lineage_map.get(
         to_table_raw_name
@@ -206,9 +210,9 @@ def _build_table_lineage(
         from_table_raw_name=str(from_table_raw_name),
         column_lineage_map=column_lineage_map,
     )
-    lineage_details = None
+    lineage_details = LineageDetails(sqlQuery=query)
     if col_lineage:
-        lineage_details = LineageDetails(sqlQuery=query, columnsLineage=col_lineage)
+        lineage_details.columnsLineage = col_lineage
     if from_entity and to_entity:
         lineage = AddLineageRequest(
             edge=EntitiesEdge(
@@ -227,6 +231,7 @@ def _build_table_lineage(
         yield lineage
 
 
+# pylint: disable=too-many-arguments
 def _create_lineage_by_table_name(
     metadata: OpenMetadata,
     from_table: str,
@@ -277,11 +282,16 @@ def _create_lineage_by_table_name(
 
 
 def populate_column_lineage_map(raw_column_lineage):
+    """populate column lineage map
+
+    Args:
+        raw_column_lineage (_type_): raw column lineage
+    """
     lineage_map = {}
     if not raw_column_lineage or len(raw_column_lineage[0]) != 2:
         return lineage_map
     for source, target in raw_column_lineage:
-        for parent in source._parent:
+        for parent in source._parent:  # pylint: disable=protected-access
             if lineage_map.get(str(target.parent)):
                 ele = lineage_map.get(str(target.parent))
                 if ele.get(str(parent)):
@@ -311,25 +321,17 @@ def get_lineage_by_query(
     This method parses the query to get source, target and intermediate table names to create lineage,
     and returns True if target table is found to create lineage otherwise returns False.
     """
-    # Prevent sqllineage from modifying the logger config
-    # Disable the DictConfigurator.configure method while importing LineageRunner
-    configure = DictConfigurator.configure
-    DictConfigurator.configure = lambda _: None
-    from sqllineage.runner import LineageRunner
-
-    # Reverting changes after import is done
-    DictConfigurator.configure = configure
     column_lineage = {}
 
     try:
         logger.debug(f"Running lineage with query: {query}")
-        result = LineageRunner(clean_raw_query(query))
+        lineage_parser = LineageParser(query)
 
-        raw_column_lineage = result.get_column_lineage()
+        raw_column_lineage = lineage_parser.column_lineage
         column_lineage.update(populate_column_lineage_map(raw_column_lineage))
 
-        for intermediate_table in result.intermediate_tables:
-            for source_table in result.source_tables:
+        for intermediate_table in lineage_parser.intermediate_tables:
+            for source_table in lineage_parser.source_tables:
                 yield from _create_lineage_by_table_name(
                     metadata,
                     from_table=str(source_table),
@@ -340,7 +342,7 @@ def get_lineage_by_query(
                     query=query,
                     column_lineage_map=column_lineage,
                 )
-            for target_table in result.target_tables:
+            for target_table in lineage_parser.target_tables:
                 yield from _create_lineage_by_table_name(
                     metadata,
                     from_table=str(intermediate_table),
@@ -351,9 +353,9 @@ def get_lineage_by_query(
                     query=query,
                     column_lineage_map=column_lineage,
                 )
-        if not result.intermediate_tables:
-            for target_table in result.target_tables:
-                for source_table in result.source_tables:
+        if not lineage_parser.intermediate_tables:
+            for target_table in lineage_parser.target_tables:
+                for source_table in lineage_parser.source_tables:
                     yield from _create_lineage_by_table_name(
                         metadata,
                         from_table=str(source_table),
@@ -377,22 +379,30 @@ def get_lineage_via_table_entity(
     service_name: str,
     query: str,
 ) -> Optional[Iterator[AddLineageRequest]]:
-    # Prevent sqllineage from modifying the logger config
-    # Disable the DictConfigurator.configure method while importing LineageRunner
-    configure = DictConfigurator.configure
-    DictConfigurator.configure = lambda _: None
-    from sqllineage.runner import LineageRunner
+    """Get lineage from table entity
 
-    # Reverting changes after import is done
-    DictConfigurator.configure = configure
+    Args:
+        metadata (OpenMetadata): OM Server client Object
+        table_entity (Table): table entity
+        database_name (str): name of the database
+        schema_name (str): name of the schema
+        service_name (str): name of the service
+        query (str): query used for lineage
+
+    Returns:
+        Optional[Iterator[AddLineageRequest]]
+
+    Yields:
+        Iterator[Optional[Iterator[AddLineageRequest]]]
+    """
     column_lineage = {}
 
     try:
         logger.debug(f"Getting lineage via table entity using query: {query}")
-        parser = LineageRunner(clean_raw_query(query))
+        lineage_parser = LineageParser(query)
         to_table_name = table_entity.name.__root__
 
-        for from_table_name in parser.source_tables:
+        for from_table_name in lineage_parser.source_tables:
             yield from _create_lineage_by_table_name(
                 metadata,
                 from_table=str(from_table_name),
