@@ -107,7 +107,6 @@ class ClientConfig(ConfigModel):
     verify: Optional[Union[bool, str]] = None
 
 
-# pylint: disable=too-many-instance-attributes
 class REST:
     """
     REST client wrapper to manage requests with
@@ -127,7 +126,6 @@ class REST:
         self._auth_token_mode = self.config.auth_token_mode
         self._verify = self.config.verify
 
-    # pylint: disable=too-many-arguments
     def _request(
         self,
         method,
@@ -182,7 +180,7 @@ class REST:
             except RetryException:
                 retry_wait = self._retry_wait * (total_retries - retry + 1)
                 logger.warning(
-                    "sleep %s seconds and retrying %s " "%s more time(s)...",
+                    "sleep %s seconds and retrying %s %s more time(s)...",
                     retry_wait,
                     url,
                     retry,
@@ -217,7 +215,13 @@ class REST:
                 f"Unexpected error calling [{url}] with method [{method}]: {exc}"
             )
         if resp.text != "":
-            return resp.json()
+            try:
+                return resp.json()
+            except Exception as exc:
+                logger.debug(traceback.format_exc())
+                logger.warning(
+                    f"Unexpected error while returing response {resp} in json format - {exc}"
+                )
         return None
 
     def get(self, path, data=None):
