@@ -15,29 +15,37 @@ To be used by OpenMetadata class
 """
 import json
 import traceback
-from typing import List, Optional
+from typing import List, Optional, Type, TypeVar
+
+from pydantic import BaseModel
+from requests.utils import quote
 
 from metadata.generated.schema.api.data.createTableProfile import (
     CreateTableProfileRequest,
 )
 from metadata.generated.schema.entity.data.location import Location
 from metadata.generated.schema.entity.data.table import (
+    ColumnProfile,
     DataModel,
     SqlQuery,
     Table,
     TableData,
     TableJoins,
+    TableProfile,
     TableProfilerConfig,
 )
+from metadata.generated.schema.type.basic import FullyQualifiedEntityName, Uuid
 from metadata.generated.schema.type.usageRequest import UsageRequest
 from metadata.ingestion.ometa.client import REST
-from metadata.ingestion.ometa.utils import ometa_logger
+from metadata.ingestion.ometa.models import EntityList
+from metadata.ingestion.ometa.utils import model_str, ometa_logger
 from metadata.utils.lru_cache import LRUCache
 from metadata.utils.uuid_encoder import UUIDEncoder
 
 logger = ometa_logger()
 
 LRU_CACHE_SIZE = 4096
+T = TypeVar("T", bound=BaseModel)
 
 
 class OMetaTableMixin:
@@ -63,7 +71,7 @@ class OMetaTableMixin:
 
     def ingest_table_sample_data(
         self, table: Table, sample_data: TableData
-    ) -> TableData:
+    ) -> Optional[TableData]:
         """
         PUT sample data for a table
 
@@ -96,6 +104,41 @@ class OMetaTableMixin:
                     f"Error trying to parse sample data results from {table.fullyQualifiedName.__root__}: {exc}"
                 )
 
+        return None
+
+    def get_sample_data(self, table: Table) -> Optional[Table]:
+        """
+        GET call for the /sampleData endpoint for a given Table
+
+        Returns a Table entity with TableData (sampleData informed)
+        """
+        resp = None
+        try:
+            resp = self.client.get(
+                f"{self.get_suffix(Table)}/{table.id.__root__}/sampleData",
+            )
+        except Exception as exc:
+            logger.debug(traceback.format_exc())
+            logger.warning(
+                f"Error trying to GET sample data for {table.fullyQualifiedName.__root__}: {exc}"
+            )
+
+        if resp:
+            try:
+                return Table(**resp)
+            except UnicodeError as err:
+                logger.debug(traceback.format_exc())
+                logger.warning(
+                    f"Unicode Error parsing the sample data response from {table.fullyQualifiedName.__root__}: {err}"
+                )
+            except Exception as exc:
+                logger.debug(traceback.format_exc())
+                logger.warning(
+                    f"Error trying to parse sample data results from {table.fullyQualifiedName.__root__}: {exc}"
+                )
+
+        return None
+
     def ingest_profile_data(
         self, table: Table, profile_request: CreateTableProfileRequest
     ) -> Table:
@@ -175,7 +218,7 @@ class OMetaTableMixin:
 
     def _create_or_update_table_profiler_config(
         self,
-        table: Table,
+        table_id: Uuid,
         table_profiler_config: TableProfilerConfig,
     ):
         """create or update profler config
@@ -189,7 +232,7 @@ class OMetaTableMixin:
 
         """
         resp = self.client.put(
-            f"{self.get_suffix(Table)}/{table.id.__root__}/tableProfilerConfig",
+            f"{self.get_suffix(Table)}/{model_str(table_id)}/tableProfilerConfig",
             data=table_profiler_config.json(),
         )
         return Table(**resp)
@@ -208,8 +251,83 @@ class OMetaTableMixin:
         table = self.get_by_name(entity=Table, fqn=fqn)
         if table:
             return self._create_or_update_table_profiler_config(
-                table=table,
+                table.id,
                 table_profiler_config=table_profiler_config,
             )
 
         return None
+
+    def get_profile_data(
+        self,
+        fqn: str,
+        start_ts: int,
+        end_ts: int,
+        limit=100,
+        after=None,
+        profile_type: Type[T] = TableProfile,
+    ) -> EntityList[T]:
+        """Get profile data
+
+        Args:
+            fqn (str): fullyQualifiedName
+            start_ts (int): start timestamp
+            end_ts (int): end timestamp
+            limit (int, optional): limit of record to return. Defaults to 100.
+            after (_type_, optional): use for API pagination. Defaults to None.
+            profile_type (Union[Type[TableProfile], Type[ColumnProfile]], optional):
+                Profile type to retrieve. Defaults to TableProfile.
+
+        Raises:
+            TypeError: if `profile_type` is not TableProfile or ColumnProfile
+
+        Returns:
+            EntityList: EntityList list object
+        """
+
+        url_after = f"&after={after}" if after else ""
+        profile_type_url = profile_type.__name__[0].lower() + profile_type.__name__[1:]
+        resp = self.client.get(
+            f"{self.get_suffix(Table)}/{fqn}/{profile_type_url}?limit={limit}{url_after}",
+            data={"startTs": start_ts // 1000, "endTs": end_ts // 1000},
+        )
+
+        if profile_type is TableProfile:
+            data: List[T] = [TableProfile(**datum) for datum in resp["data"]]  # type: ignore
+        elif profile_type is ColumnProfile:
+            split_fqn = fqn.split(".")
+            if len(split_fqn) < 5:
+                raise ValueError(f"{fqn} is not a column fqn")
+            data: List[T] = [ColumnProfile(**datum) for datum in resp["data"]]  # type: ignore
+        else:
+            raise TypeError(
+                f"{profile_type} is not an accepeted type."
+                "Type must be `TableProfile` or `ColumnProfile`"
+            )
+        total = resp["paging"]["total"]
+        after = resp["paging"]["after"] if "after" in resp["paging"] else None
+
+        return EntityList(entities=data, total=total, after=after)
+
+    def get_latest_table_profile(
+        self, fqn: FullyQualifiedEntityName
+    ) -> Optional[Table]:
+        """Get the latest profile data for a table
+
+        Args:
+            fqn (str): table fully qualified name
+
+        Returns:
+            Optional[Table]: OM table object
+        """
+        return self._get(Table, f"{quote(model_str(fqn))}/tableProfile/latest")
+
+    def get_table_queries(self, table_id: Uuid) -> Optional[Table]:
+        """Get the queries attached to a table
+
+        Args:
+            id (str): table fully qualified name
+
+        Returns:
+            Optional[Table]: OM table object
+        """
+        return self._get(Table, f"{model_str(table_id)}/tableQuery")
