@@ -17,17 +17,6 @@ working with OpenMetadata entities.
 import traceback
 from typing import Dict, Generic, Iterable, List, Optional, Type, TypeVar, Union
 
-from metadata.generated.schema.entity.bot import BotType
-from metadata.ingestion.ometa.mixins.dashboard_mixin import OMetaDashboardMixin
-from metadata.ingestion.ometa.mixins.patch_mixin import OMetaPatchMixin
-from metadata.ingestion.ometa.ssl_registry import (
-    InvalidSSLVerificationException,
-    ssl_verification_registry,
-)
-from metadata.utils.secrets.secrets_manager_factory import (
-    get_secrets_manager_from_om_connection,
-)
-
 try:
     from typing import get_args
 except ImportError:
@@ -36,7 +25,12 @@ except ImportError:
 from pydantic import BaseModel
 from requests.utils import quote
 
+from metadata.generated.schema.analytics.webAnalyticEventData import (
+    WebAnalyticEventData,
+)
 from metadata.generated.schema.api.lineage.addLineage import AddLineageRequest
+from metadata.generated.schema.dataInsight.dataInsightChart import DataInsightChart
+from metadata.generated.schema.dataInsight.kpi.kpi import Kpi
 from metadata.generated.schema.entity.data.chart import Chart
 from metadata.generated.schema.entity.data.dashboard import Dashboard
 from metadata.generated.schema.entity.data.database import Database
@@ -56,7 +50,11 @@ from metadata.generated.schema.entity.services.connections.metadata.openMetadata
 )
 from metadata.generated.schema.entity.services.dashboardService import DashboardService
 from metadata.generated.schema.entity.services.databaseService import DatabaseService
+from metadata.generated.schema.entity.services.ingestionPipelines.ingestionPipeline import (
+    IngestionPipeline,
+)
 from metadata.generated.schema.entity.services.messagingService import MessagingService
+from metadata.generated.schema.entity.services.metadataService import MetadataService
 from metadata.generated.schema.entity.services.mlmodelService import MlModelService
 from metadata.generated.schema.entity.services.pipelineService import PipelineService
 from metadata.generated.schema.entity.services.storageService import StorageService
@@ -74,9 +72,15 @@ from metadata.generated.schema.type.entityReference import EntityReference
 from metadata.ingestion.models.encoders import show_secrets_encoder
 from metadata.ingestion.ometa.auth_provider import AuthenticationProvider
 from metadata.ingestion.ometa.client import REST, APIError, ClientConfig
+from metadata.ingestion.ometa.mixins.dashboard_mixin import OMetaDashboardMixin
+from metadata.ingestion.ometa.mixins.data_insight_mixin import DataInsightMixin
 from metadata.ingestion.ometa.mixins.es_mixin import ESMixin
 from metadata.ingestion.ometa.mixins.glossary_mixin import GlossaryMixin
+from metadata.ingestion.ometa.mixins.ingestion_pipeline_mixin import (
+    OMetaIngestionPipelineMixin,
+)
 from metadata.ingestion.ometa.mixins.mlmodel_mixin import OMetaMlModelMixin
+from metadata.ingestion.ometa.mixins.patch_mixin import OMetaPatchMixin
 from metadata.ingestion.ometa.mixins.pipeline_mixin import OMetaPipelineMixin
 from metadata.ingestion.ometa.mixins.server_mixin import OMetaServerMixin
 from metadata.ingestion.ometa.mixins.service_mixin import OMetaServiceMixin
@@ -84,12 +88,16 @@ from metadata.ingestion.ometa.mixins.table_mixin import OMetaTableMixin
 from metadata.ingestion.ometa.mixins.tag_mixin import OMetaTagMixin
 from metadata.ingestion.ometa.mixins.tests_mixin import OMetaTestsMixin
 from metadata.ingestion.ometa.mixins.topic_mixin import OMetaTopicMixin
+from metadata.ingestion.ometa.mixins.user_mixin import OMetaUserMixin
 from metadata.ingestion.ometa.mixins.version_mixin import OMetaVersionMixin
+from metadata.ingestion.ometa.models import EntityList
 from metadata.ingestion.ometa.provider_registry import (
     InvalidAuthProviderException,
     auth_provider_registry,
 )
 from metadata.ingestion.ometa.utils import get_entity_type, model_str, ometa_logger
+from metadata.utils.secrets.secrets_manager_factory import SecretsManagerFactory
+from metadata.utils.ssl_registry import get_verify_ssl_fn
 
 logger = ometa_logger()
 
@@ -118,21 +126,6 @@ class EmptyPayloadException(Exception):
     """
 
 
-class EntityList(Generic[T], BaseModel):
-    """
-    Pydantic Entity list model
-
-    Attributes
-        entities (List): list of entities
-        total (int):
-        after (str):
-    """
-
-    entities: List[T]
-    total: int
-    after: str = None
-
-
 class OpenMetadata(
     OMetaPipelineMixin,
     OMetaMlModelMixin,
@@ -147,6 +140,9 @@ class OpenMetadata(
     OMetaDashboardMixin,
     OMetaPatchMixin,
     OMetaTestsMixin,
+    DataInsightMixin,
+    OMetaIngestionPipelineMixin,
+    OMetaUserMixin,
     Generic[T, C],
 ):
     """
@@ -159,6 +155,7 @@ class OpenMetadata(
 
     client: REST
     _auth_provider: AuthenticationProvider
+    config: OpenMetadataConnection
 
     class_root = ".".join(["metadata", "generated", "schema"])
     entity_path = "entity"
@@ -174,14 +171,10 @@ class OpenMetadata(
         self.config = config
 
         # Load the secrets' manager client
-        self.secrets_manager_client = get_secrets_manager_from_om_connection(
-            config, config.secretsManagerCredentials
-        )
-
-        # Load auth provider config from Secret Manager if necessary
-        self.secrets_manager_client.add_auth_provider_security_config(
-            self.config, BotType.ingestion_bot.value
-        )
+        self.secrets_manager_client = SecretsManagerFactory(
+            config.secretsManagerProvider,
+            config.secretsManagerCredentials,
+        ).get_secrets_manager()
 
         # Load the auth provider init from the registry
         auth_provider_fn = auth_provider_registry.registry.get(
@@ -194,20 +187,14 @@ class OpenMetadata(
 
         self._auth_provider = auth_provider_fn(self.config)
 
-        get_verify_ssl = ssl_verification_registry.registry.get(
-            self.config.verifySSL.value
-        )
-        if not get_verify_ssl:
-            raise InvalidSSLVerificationException(
-                f"Cannot find {self.config.verifySSL.value} in {ssl_verification_registry.registry}"
-            )
+        get_verify_ssl = get_verify_ssl_fn(self.config.verifySSL)
 
         client_config: ClientConfig = ClientConfig(
             base_url=self.config.hostPort,
             api_version=self.config.apiVersion,
             auth_header="Authorization",
             auth_token=self._auth_provider.get_access_token,
-            verify=get_verify_ssl(config),
+            verify=get_verify_ssl(self.config.sslConfig),
         )
         self.client = REST(client_config)
         self._use_raw_data = raw_data
@@ -371,6 +358,20 @@ class OpenMetadata(
         ):
             return "/services/mlmodelServices"
 
+        if issubclass(
+            entity,
+            get_args(
+                Union[MetadataService, self.get_create_entity_type(MetadataService)]
+            ),
+        ):
+            return "/services/metadataServices"
+
+        if issubclass(
+            entity,
+            IngestionPipeline,
+        ):
+            return "/services/ingestionPipelines"
+
         if issubclass(
             entity,
             get_args(
@@ -391,6 +392,18 @@ class OpenMetadata(
         ):
             return "/testCase"
 
+        if issubclass(entity, WebAnalyticEventData):
+            return "/analytics/webAnalyticEvent/collect"
+
+        if issubclass(entity, DataInsightChart):
+            return "/dataInsight"
+
+        if issubclass(
+            entity,
+            Kpi,
+        ):
+            return "/kpi"
+
         raise MissingEntityTypeException(
             f"Missing {entity} type when generating suffixes"
         )
@@ -558,8 +571,8 @@ class OpenMetadata(
             return entity(**resp)
         except APIError as err:
             logger.debug(traceback.format_exc())
-            logger.warning(
-                "GET %s for %s." "Error %s - %s",
+            logger.debug(
+                "GET %s for %s. Error %s - %s",
                 entity.__name__,
                 path,
                 err.status_code,
@@ -586,10 +599,9 @@ class OpenMetadata(
                 description=instance.description,
                 href=instance.href,
             )
-        logger.warning("Cannot find the Entity %s", fqn)
+        logger.debug("Cannot find the Entity %s", fqn)
         return None
 
-    # pylint: disable=too-many-arguments,dangerous-default-value
     def list_entities(
         self,
         entity: Type[T],
