@@ -15,9 +15,9 @@ import json
 import traceback
 from typing import Iterable, List, Optional
 
+from pydantic import BaseModel, Extra
 from requests.utils import urlparse
-from tableau_api_lib.utils.querying import get_views_dataframe, get_workbooks_dataframe
-from tableau_api_lib.utils.querying.users import get_all_user_fields
+from tableau_api_lib.utils import extract_pages
 
 from metadata.generated.schema.api.data.createChart import CreateChartRequest
 from metadata.generated.schema.api.data.createDashboard import CreateDashboardRequest
@@ -26,8 +26,6 @@ from metadata.generated.schema.api.tags.createTag import CreateTagRequest
 from metadata.generated.schema.api.tags.createTagCategory import (
     CreateTagCategoryRequest,
 )
-from metadata.generated.schema.api.teams.createUser import CreateUserRequest
-from metadata.generated.schema.entity.data.chart import Chart
 from metadata.generated.schema.entity.data.dashboard import (
     Dashboard as LineageDashboard,
 )
@@ -42,43 +40,73 @@ from metadata.generated.schema.entity.tags.tagCategory import Tag
 from metadata.generated.schema.metadataIngestion.workflow import (
     Source as WorkflowSource,
 )
-from metadata.generated.schema.type.entityLineage import EntitiesEdge
 from metadata.generated.schema.type.entityReference import EntityReference
 from metadata.generated.schema.type.tagLabel import TagLabel
 from metadata.ingestion.api.source import InvalidSourceException, SourceStatus
 from metadata.ingestion.models.ometa_tag_category import OMetaTagAndCategory
 from metadata.ingestion.source.dashboard.dashboard_service import DashboardServiceSource
 from metadata.utils import fqn
+from metadata.utils.constants import (
+    TABLEAU_GET_VIEWS_PARAM_DICT,
+    TABLEAU_GET_WORKBOOKS_PARAM_DICT,
+)
 from metadata.utils.filters import filter_by_chart
+from metadata.utils.graphql_queries import TABLEAU_LINEAGE_GRAPHQL_QUERY
 from metadata.utils.helpers import get_standard_chart_type
 from metadata.utils.logger import ingestion_logger
 
 logger = ingestion_logger()
+
 TABLEAU_TAG_CATEGORY = "TableauTags"
 
-TABLEAU_LINEAGE_GRAPHQL_QUERY = """
-{
-  workbooks {
-    id
-    luid
-    name
-    upstreamTables{
-      name
-      schema
-      upstreamDatabases{
-        name
-      }
-      referencedByQueries{
-        name
-        query
-      }
-    }
-  }
-}
-"""
+
+class TableauBaseModel(BaseModel):
+    """
+    Tableau basic configurations
+    """
+
+    class Config:
+        extra = Extra.allow
+
+    id: str
+    name: str
+
+
+class TableauOwner(TableauBaseModel):
+    """
+    Tableau Owner Details
+    """
+
+    email: str
+
+
+class TableauChart(TableauBaseModel):
+    """
+    Chart (View) representation from API
+    """
+
+    workbook_id: str
+    sheet_type: str
+    view_url_name: str
+    tags: List[str]
+
+
+class TableauDashboard(TableauBaseModel):
+    """
+    Response from Tableau API
+    """
+
+    description: Optional[str]
+    tags: List[str]
+    owner: TableauOwner
+    charts: Optional[List[TableauChart]]
+    webpage_url: Optional[str]
 
 
 class TableauSource(DashboardServiceSource):
+    """
+    Tableau Source Class
+    """
 
     config: WorkflowSource
     metadata_config: OpenMetadataConnection
@@ -91,51 +119,85 @@ class TableauSource(DashboardServiceSource):
     ):
 
         super().__init__(config, metadata_config)
-        self.workbooks = {}
-        self.tags = []
-        self.owner = {}
-        self.workboook_datasources = {}
+        self.workbooks = None  # We will populate this in `prepare`
+        self.tags = set()  # To create the tags before yielding final entities
+        self.workbook_datasources = {}
 
     def prepare(self):
-        # Restructuring the api response for workbooks
-        workbook_details = get_workbooks_dataframe(self.client).to_dict()
-        for i in range(len(workbook_details.get("id"))):
-            workbook = {
-                key: workbook_details[key][i] for key in workbook_details.keys()
-            }
-            workbook["charts"] = []
-            self.workbooks[workbook_details["id"][i]] = workbook
-
-        # Restructuring the api response for views and attaching views to their respective workbooks
-        all_views_details = get_views_dataframe(self.client).to_dict()
-        for i in range(len(all_views_details.get("id"))):
-            chart = {
-                key: all_views_details[key][i]
-                for key in all_views_details.keys()
-                if key != "workbook"
-            }
-            self.workbooks[all_views_details["workbook"][i]["id"]]["charts"].append(
-                chart
+        """
+        Restructure the API response to
+        """
+        # Available fields information:
+        # https://help.tableau.com/current/api/rest_api/en-us/REST/rest_api_concepts_fields.htm#query_workbooks_site
+        # We can also get project.description as folder
+        self.workbooks = [
+            TableauDashboard(
+                id=workbook["id"],
+                name=workbook["name"],
+                description=workbook.get("description"),
+                tags=[
+                    tag["label"] for tag in workbook.get("tags", {}).get("tag") or []
+                ],
+                owner=TableauOwner(
+                    id=workbook.get("owner", {}).get("id"),
+                    name=workbook.get("owner", {}).get("name"),
+                    email=workbook.get("owner", {}).get("email"),
+                ),
+                webpage_url=workbook.get("webpageUrl"),
             )
+            for workbook in extract_pages(
+                self.client.query_workbooks_for_site,
+                parameter_dict=TABLEAU_GET_WORKBOOKS_PARAM_DICT,
+            )
+        ]
+
+        # For charts, we can also pick up usage as a field
+        charts = [
+            TableauChart(
+                id=chart["id"],
+                name=chart["name"],
+                # workbook.id is always included in the response
+                workbook_id=chart["workbook"]["id"],
+                sheet_type=chart["sheetType"],
+                view_url_name=chart["viewUrlName"],
+                tags=[tag["label"] for tag in chart.get("tags", {}).get("tag") or []],
+            )
+            for chart in extract_pages(
+                self.client.query_views_for_site,
+                content_id=self.client.site_id,
+                parameter_dict=TABLEAU_GET_VIEWS_PARAM_DICT,
+            )
+        ]
+
+        # Add all the charts (views) from the API to each workbook
+        for workbook in self.workbooks:
+            workbook.charts = [
+                chart for chart in charts if chart.workbook_id == workbook.id
+            ]
 
         # Collecting all view & workbook tags
-        for _, tags in workbook_details.get("tags").items():
-            self.tags.extend([tag["label"] for tag in tags.get("tag", [])])
+        for container in [self.workbooks, charts]:
+            for elem in container:
+                self.tags.update(elem.tags)
 
-        for _, tags in all_views_details.get("tags").items():
-            self.tags.extend([tag["label"] for tag in tags.get("tag", [])])
-
-        # Fetch User/Owner Details
-        owner = get_all_user_fields(self.client)
-        self.owner = {user["id"]: user for user in owner}
-
-        # Fetch Datasource information for lineage
-        graphql_query_result = self.client.metadata_graphql_query(
-            query=TABLEAU_LINEAGE_GRAPHQL_QUERY
-        )
-        self.workboook_datasources = json.loads(graphql_query_result.text)["data"].get(
-            "workbooks"
-        )
+        if self.source_config.dbServiceNames:
+            try:
+                # Fetch Datasource information for lineage
+                graphql_query_result = self.client.metadata_graphql_query(
+                    query=TABLEAU_LINEAGE_GRAPHQL_QUERY
+                )
+                self.workbook_datasources = json.loads(graphql_query_result.text)[
+                    "data"
+                ].get("workbooks")
+            except Exception:
+                logger.debug(traceback.format_exc())
+                logger.warning(
+                    "\nSomething went wrong while connecting to Tableau Metadata APIs\n"
+                    "Please check if the Tableau Metadata APIs are enabled for you Tableau instance\n"
+                    "For more information on enabling the Tableau Metadata APIs follow the link below\n"
+                    "https://help.tableau.com/current/api/metadata_api/en-us/docs/meta_api_start.html"
+                    "#enable-the-tableau-metadata-api-for-tableau-server\n"
+                )
 
         return super().prepare()
 
@@ -149,27 +211,28 @@ class TableauSource(DashboardServiceSource):
             )
         return cls(config, metadata_config)
 
-    def get_dashboards_list(self) -> Optional[List[dict]]:
+    def get_dashboards_list(self) -> Optional[List[TableauDashboard]]:
         """
         Get List of all dashboards
         """
-        return self.workbooks.values()
+        return self.workbooks
 
-    def get_dashboard_name(self, dashboard_details: dict) -> str:
+    def get_dashboard_name(self, dashboard: TableauDashboard) -> str:
         """
         Get Dashboard Name
         """
-        return dashboard_details.get("name")
+        return dashboard.name
 
-    def get_dashboard_details(self, dashboard: dict) -> dict:
+    def get_dashboard_details(self, dashboard: TableauDashboard) -> TableauDashboard:
         """
-        Get Dashboard Details
+        Get Dashboard Details. Returning the identity here as we prepare everything
+        during the `prepare` stage
         """
         return dashboard
 
-    def yield_owner(
-        self, dashboard_details: dict
-    ) -> Optional[Iterable[CreateUserRequest]]:
+    def get_owner_details(
+        self, dashboard_details: TableauDashboard
+    ) -> Optional[EntityReference]:
         """Get dashboard owner
 
         Args:
@@ -177,14 +240,13 @@ class TableauSource(DashboardServiceSource):
         Returns:
             Optional[EntityReference]
         """
-        owner = self.owner[dashboard_details["owner"]["id"]]
-        name = owner.get("name")
-        displayName = owner.get("fullName")
-        email = owner.get("email")
-        if name and email:
-            yield CreateUserRequest(name=name, displayName=displayName, email=email)
+        if dashboard_details.owner.email:
+            user = self.metadata.get_user_by_email(dashboard_details.owner.email)
+            if user:
+                return EntityReference(id=user.id.__root__, type="user")
+        return None
 
-    def yield_tag(self, _) -> OMetaTagAndCategory:
+    def yield_tag(self, _) -> OMetaTagAndCategory:  # pylint: disable=arguments-differ
         """
         Fetch Dashboard Tags
         """
@@ -193,7 +255,6 @@ class TableauSource(DashboardServiceSource):
                 category_name=CreateTagCategoryRequest(
                     name=TABLEAU_TAG_CATEGORY,
                     description="Tags associates with tableau entities",
-                    categoryType="Descriptive",
                 ),
                 category_details=CreateTagRequest(name=tag, description="Tableau Tag"),
             )
@@ -202,62 +263,57 @@ class TableauSource(DashboardServiceSource):
                 f"Tag Category {TABLEAU_TAG_CATEGORY}, Primary Tag {tag} Ingested"
             )
 
-    def get_tag_lables(self, tags: dict) -> Optional[List[TagLabel]]:
-        if tags.get("tag"):
-            return [
-                TagLabel(
-                    tagFQN=fqn.build(
-                        self.metadata,
-                        Tag,
-                        tag_category_name=TABLEAU_TAG_CATEGORY,
-                        tag_name=tag["label"],
-                    ),
-                    labelType="Automated",
-                    state="Suggested",
-                    source="Tag",
-                )
-                for tag in tags["tag"]
-            ]
-        return []
+    def get_tag_labels(self, tags: List[str]) -> Optional[List[TagLabel]]:
+        return [
+            TagLabel(
+                tagFQN=fqn.build(
+                    self.metadata,
+                    Tag,
+                    tag_category_name=TABLEAU_TAG_CATEGORY,
+                    tag_name=tag,
+                ),
+                labelType="Automated",
+                state="Suggested",
+                source="Tag",
+            )
+            for tag in tags
+        ]
 
     def yield_dashboard(
-        self, dashboard_details: dict
+        self, dashboard_details: TableauDashboard
     ) -> Iterable[CreateDashboardRequest]:
         """
         Method to Get Dashboard Entity
         """
-        dashboard_tag = dashboard_details.get("tags")
-        workbook_url = urlparse(dashboard_details.get("webpageUrl")).fragment
-        dashboard_url = f"#{workbook_url}"
+        workbook_url = urlparse(dashboard_details.webpage_url).fragment
         yield CreateDashboardRequest(
-            name=dashboard_details.get("id"),
-            displayName=dashboard_details.get("name"),
-            description="",
-            owner=self.context.owner,
+            name=dashboard_details.id,
+            displayName=dashboard_details.name,
+            description=dashboard_details.description,
+            owner=self.get_owner_details(dashboard_details),
             charts=[
                 EntityReference(id=chart.id.__root__, type="chart")
                 for chart in self.context.charts
             ],
-            tags=self.get_tag_lables(dashboard_tag),
-            dashboardUrl=dashboard_url,
+            tags=self.get_tag_labels(dashboard_details.tags),
+            dashboardUrl=f"#{workbook_url}",
             service=EntityReference(
                 id=self.context.dashboard_service.id.__root__, type="dashboardService"
             ),
         )
 
     def yield_dashboard_lineage_details(
-        self, dashboard_details: dict, db_service_name: str
+        self, dashboard_details: TableauDashboard, db_service_name: str
     ) -> Optional[Iterable[AddLineageRequest]]:
         """
         Get lineage between dashboard and data sources
         """
 
-        dashboard_id = dashboard_details.get("id")
         data_source = next(
             (
                 data_source
-                for data_source in self.workboook_datasources
-                if data_source.get("luid") == dashboard_id
+                for data_source in self.workbook_datasources or []
+                if data_source.get("luid") == dashboard_details.id
             ),
             None,
         )
@@ -265,7 +321,7 @@ class TableauSource(DashboardServiceSource):
             self.metadata,
             entity_type=LineageDashboard,
             service_name=self.config.serviceName,
-            dashboard_name=dashboard_id,
+            dashboard_name=dashboard_details.id,
         )
         to_entity = self.metadata.get_by_name(
             entity=LineageDashboard,
@@ -276,35 +332,23 @@ class TableauSource(DashboardServiceSource):
             upstream_tables = data_source.get("upstreamTables")
             for upstream_table in upstream_tables:
                 database_schema_table = fqn.split_table_name(upstream_table.get("name"))
-                database_name = database_schema_table.get("database")
-                schema_name = database_schema_table.get("database_schema")
-                table_name = database_schema_table.get("table")
                 from_fqn = fqn.build(
                     self.metadata,
                     entity_type=Table,
                     service_name=db_service_name,
-                    schema_name=schema_name
-                    if schema_name
-                    else upstream_table.get("schema"),
-                    table_name=table_name,
-                    database_name=database_name,
+                    schema_name=database_schema_table.get(
+                        "database_schema", upstream_table.get("schema")
+                    ),
+                    table_name=database_schema_table.get("table"),
+                    database_name=database_schema_table.get("database"),
                 )
                 from_entity = self.metadata.get_by_name(
                     entity=Table,
                     fqn=from_fqn,
                 )
-                if from_entity and to_entity:
-                    lineage = AddLineageRequest(
-                        edge=EntitiesEdge(
-                            fromEntity=EntityReference(
-                                id=from_entity.id.__root__, type="table"
-                            ),
-                            toEntity=EntityReference(
-                                id=to_entity.id.__root__, type="dashboard"
-                            ),
-                        )
-                    )
-                    yield lineage
+                yield self._get_add_lineage_request(
+                    to_entity=to_entity, from_entity=from_entity
+                )
         except (Exception, IndexError) as err:
             logger.debug(traceback.format_exc())
             logger.error(
@@ -312,43 +356,43 @@ class TableauSource(DashboardServiceSource):
             )
 
     def yield_dashboard_chart(
-        self, dashboard_details: dict
+        self, dashboard_details: TableauDashboard
     ) -> Optional[Iterable[CreateChartRequest]]:
         """
         Method to fetch charts linked to dashboard
         """
-        for chart in dashboard_details.get("charts"):
+        for chart in dashboard_details.charts or []:
             try:
-                if filter_by_chart(
-                    self.source_config.chartFilterPattern, chart["name"]
-                ):
-                    self.status.filter(chart["name"], "Chart Pattern not allowed")
+                if filter_by_chart(self.source_config.chartFilterPattern, chart.name):
+                    self.status.filter(chart.name, "Chart Pattern not allowed")
                     continue
-                workbook_name = dashboard_details["name"].replace(" ", "")
+                workbook_name = dashboard_details.name.replace(" ", "")
                 site_url = (
                     f"site/{self.service_connection.siteUrl}/"
                     if self.service_connection.siteUrl
                     else ""
                 )
                 chart_url = (
-                    f"#/{site_url}" f"views/{workbook_name}/" f"{chart['viewUrlName']}"
+                    f"#/{site_url}" f"views/{workbook_name}/" f"{chart.view_url_name}"
                 )
                 yield CreateChartRequest(
-                    name=chart["id"],
-                    displayName=chart["name"],
-                    description="",
-                    chartType=get_standard_chart_type(chart["sheetType"]),
+                    name=chart.id,
+                    displayName=chart.name,
+                    chartType=get_standard_chart_type(chart.sheet_type),
                     chartUrl=chart_url,
-                    tags=self.get_tag_lables(chart["tags"]),
+                    tags=self.get_tag_labels(chart.tags),
                     service=EntityReference(
                         id=self.context.dashboard_service.id.__root__,
                         type="dashboardService",
                     ),
                 )
-                self.status.scanned(chart["id"])
+                self.status.scanned(chart.id)
             except Exception as exc:
                 logger.debug(traceback.format_exc())
                 logger.warning(f"Error to yield dashboard chart [{chart}]: {exc}")
 
     def close(self):
-        self.client.sign_out()
+        try:
+            self.client.sign_out()
+        except ConnectionError as err:
+            logger.debug(f"Error closing connection - {err}")
