@@ -27,10 +27,6 @@ from metadata.generated.schema.api.lineage.addLineage import AddLineageRequest
 from metadata.generated.schema.api.services.createStorageService import (
     CreateStorageServiceRequest,
 )
-from metadata.generated.schema.api.tags.createTag import CreateTagRequest
-from metadata.generated.schema.api.tags.createTagCategory import (
-    CreateTagCategoryRequest,
-)
 from metadata.generated.schema.entity.data.database import Database
 from metadata.generated.schema.entity.data.databaseSchema import DatabaseSchema
 from metadata.generated.schema.entity.data.location import Location
@@ -71,9 +67,8 @@ from metadata.ingestion.models.topology import (
     create_source_context,
 )
 from metadata.ingestion.ometa.ometa_api import OpenMetadata
-from metadata.ingestion.source.database.dbt_source import DBTMixin
 from metadata.utils import fqn
-from metadata.utils.dbt_config import get_dbt_details
+from metadata.utils.filters import filter_by_schema
 from metadata.utils.logger import ingestion_logger
 
 logger = ingestion_logger()
@@ -125,9 +120,6 @@ class DatabaseServiceTopology(ServiceTopology):
         ],
         children=["database"],
         post_process=[
-            "process_dbt_lineage_and_descriptions",
-            "create_dbt_tests_suite_definition",
-            "create_dbt_test_cases",
             "yield_view_lineage",
         ],
     )
@@ -180,11 +172,6 @@ class DatabaseServiceTopology(ServiceTopology):
                 consumer=["storage_service"],
                 nullable=True,
             ),
-            NodeStage(
-                type_=DataModelLink,
-                processor="yield_datamodel",
-                ack_sink=False,
-            ),
             NodeStage(
                 type_=TableLocationLink,
                 processor="yield_table_location_link",
@@ -200,21 +187,23 @@ class SQLSourceStatus(SourceStatus):
     Reports the source status after ingestion
     """
 
-    success: List[str] = list()
-    failures: List[str] = list()
-    warnings: List[str] = list()
-    filtered: List[str] = list()
+    success: List[str] = []
+    failures: List[str] = []
+    warnings: List[str] = []
+    filtered: List[str] = []
 
     def scanned(self, record: str) -> None:
         self.success.append(record)
-        logger.info(f"Scanned [{record}]")
+        logger.debug(f"Scanned [{record}]")
 
-    def filter(self, record: str, err: str) -> None:
-        self.filtered.append(record)
-        logger.warning(f"Filtered [{record}] due to {err}")
+    def filter(self, key: str, reason: str) -> None:
+        logger.debug(f"Filtered [{key}] due to {reason}")
+        self.filtered.append({key: reason})
 
 
-class DatabaseServiceSource(DBTMixin, TopologyRunnerMixin, Source, ABC):
+class DatabaseServiceSource(
+    TopologyRunnerMixin, Source, ABC
+):  # pylint: disable=too-many-public-methods
     """
     Base class for Database Services.
     It implements the topology and context.
@@ -224,7 +213,7 @@ class DatabaseServiceSource(DBTMixin, TopologyRunnerMixin, Source, ABC):
     source_config: DatabaseServiceMetadataPipeline
     config: WorkflowSource
     metadata: OpenMetadata
-    database_source_state: Set
+    database_source_state: Set = set()
     # Big union of types we want to fetch dynamically
     service_connection: DatabaseConnection.__fields__["config"].type_
 
@@ -234,31 +223,8 @@ class DatabaseServiceSource(DBTMixin, TopologyRunnerMixin, Source, ABC):
     topology = DatabaseServiceTopology()
     context = create_source_context(topology)
 
-    # Initialize DBT structures for all Databases
-    data_models = {}
-    dbt_tests = {}
-
-    def __init__(self):
-
-        if (
-            hasattr(self.source_config.dbtConfigSource, "dbtSecurityConfig")
-            and self.source_config.dbtConfigSource.dbtSecurityConfig is None
-        ):
-            logger.info("dbtConfigSource is not configured")
-            self.dbt_catalog = None
-            self.dbt_manifest = None
-            self.dbt_run_results = None
-            self.data_models = {}
-        else:
-            dbt_details = get_dbt_details(self.source_config.dbtConfigSource)
-            if dbt_details:
-                self.dbt_catalog = dbt_details[0] if len(dbt_details) == 3 else None
-                self.dbt_manifest = dbt_details[1] if len(dbt_details) == 3 else None
-                self.dbt_run_results = dbt_details[2] if len(dbt_details) == 3 else None
-                self.data_models = {}
-
     def prepare(self):
-        self._parse_data_model()
+        pass
 
     def get_status(self) -> SourceStatus:
         return self.status
@@ -353,7 +319,8 @@ class DatabaseServiceSource(DBTMixin, TopologyRunnerMixin, Source, ABC):
         """
 
     def yield_location(
-        self, table_name_and_type: Tuple[str, TableType]
+        self,
+        table_name_and_type: Tuple[str, TableType],  # pylint: disable=unused-argument
     ) -> Iterable[CreateLocationRequest]:
         """
         From topology.
@@ -369,55 +336,9 @@ class DatabaseServiceSource(DBTMixin, TopologyRunnerMixin, Source, ABC):
         """
         yield from self.get_database_schema_names()
 
-    def yield_datamodel(
-        self, table_name_and_type: Tuple[str, TableType]
-    ) -> Iterable[DataModelLink]:
-        """
-        Gets the current table being processed, fetches its data model
-        and sends it ot the sink
-        """
-
-        table_name, _ = table_name_and_type
-        table_fqn = fqn.build(
-            self.metadata,
-            entity_type=Table,
-            service_name=self.context.database_service.name.__root__,
-            database_name=self.context.database.name.__root__,
-            schema_name=self.context.database_schema.name.__root__,
-            table_name=table_name,
-        )
-
-        datamodel = self.get_data_model(table_fqn)
-
-        dbt_tag_labels = None
-        if datamodel:
-            logger.info("Processing DBT Tags")
-            dbt_tag_labels = datamodel.tags
-            if not dbt_tag_labels:
-                dbt_tag_labels = []
-            for column in datamodel.columns:
-                if column.tags:
-                    dbt_tag_labels.extend(column.tags)
-            if dbt_tag_labels:
-                for tag_label in dbt_tag_labels:
-                    yield OMetaTagAndCategory(
-                        category_name=CreateTagCategoryRequest(
-                            name="DBTTags",
-                            description="",
-                            categoryType="Classification",
-                        ),
-                        category_details=CreateTagRequest(
-                            name=tag_label.tagFQN.__root__.split(".")[1],
-                            description="DBT Tags",
-                        ),
-                    )
-            yield DataModelLink(
-                fqn=table_fqn,
-                datamodel=datamodel,
-            )
-
     def yield_table_location_link(
-        self, table_name_and_type: Tuple[str, TableType]
+        self,
+        table_name_and_type: Tuple[str, TableType],  # pylint: disable=unused-argument
     ) -> Iterable[TableLocationLink]:
         """
         Gets the current location being processed, fetches its data model
@@ -522,6 +443,24 @@ class DatabaseServiceSource(DBTMixin, TopologyRunnerMixin, Source, ABC):
         for schema in schema_list:
             yield from self.delete_schema_tables(schema.fullyQualifiedName.__root__)
 
+    def _get_filtered_schema_names(self, add_to_status: bool = True) -> Iterable[str]:
+        for schema_name in self.get_raw_database_schema_names():
+            schema_fqn = fqn.build(
+                self.metadata,
+                entity_type=DatabaseSchema,
+                service_name=self.context.database_service.name.__root__,
+                database_name=self.context.database.name.__root__,
+                schema_name=schema_name,
+            )
+            if filter_by_schema(
+                self.source_config.schemaFilterPattern,
+                schema_fqn if self.source_config.useFqnForFiltering else schema_name,
+            ):
+                if add_to_status:
+                    self.status.filter(schema_fqn, "Schema Filtered Out")
+                continue
+            yield schema_name
+
     def mark_tables_as_deleted(self):
         """
         Use the current inspector to mark tables as deleted
@@ -530,8 +469,13 @@ class DatabaseServiceSource(DBTMixin, TopologyRunnerMixin, Source, ABC):
             logger.info(
                 f"Mark Deleted Tables set to True. Processing database [{self.context.database.name.__root__}]"
             )
-            if self.source_config.markDeletedTablesFromFilterOnly:
-                schema_names_list = self.get_database_schema_names()
+            # If markAllDeletedTables is True, all tables Which are not in FilterPattern will be deleted
+            if self.source_config.markAllDeletedTables:
+                yield from self.fetch_all_schema_and_delete_tables()
+
+            # If markAllDeletedTables is False (Default), Only delete tables which are deleted from the datasource
+            else:
+                schema_names_list = self._get_filtered_schema_names(add_to_status=False)
                 for schema_name in schema_names_list:
                     schema_fqn = fqn.build(
                         self.metadata,
@@ -542,5 +486,3 @@ class DatabaseServiceSource(DBTMixin, TopologyRunnerMixin, Source, ABC):
                     )
 
                     yield from self.delete_schema_tables(schema_fqn)
-            else:
-                yield from self.fetch_all_schema_and_delete_tables()
