@@ -8,9 +8,13 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-
+"""
+Vertica source implementation.
+"""
 import re
+import traceback
 from textwrap import dedent
+from typing import Iterable
 
 from sqlalchemy import sql, util
 from sqlalchemy.engine import reflection
@@ -18,6 +22,7 @@ from sqlalchemy.sql import sqltypes
 from sqlalchemy.sql.sqltypes import String
 from sqlalchemy_vertica.base import VerticaDialect
 
+from metadata.generated.schema.entity.data.database import Database
 from metadata.generated.schema.entity.services.connections.database.verticaConnection import (
     VerticaConnection,
 )
@@ -29,11 +34,22 @@ from metadata.generated.schema.metadataIngestion.workflow import (
 )
 from metadata.ingestion.api.source import InvalidSourceException
 from metadata.ingestion.source.database.common_db_source import CommonDbSourceService
+from metadata.utils import fqn
+from metadata.utils.filters import filter_by_database
+from metadata.utils.logger import ingestion_logger
 from metadata.utils.sql_queries import (
     VERTICA_GET_COLUMNS,
     VERTICA_GET_PRIMARY_KEYS,
+    VERTICA_LIST_DATABASES,
+    VERTICA_TABLE_COMMENTS,
     VERTICA_VIEW_DEFINITION,
 )
+from metadata.utils.sqlalchemy_utils import (
+    get_all_table_comments,
+    get_table_comment_wrapper,
+)
+
+logger = ingestion_logger()
 
 
 class UUID(String):
@@ -44,15 +60,18 @@ class UUID(String):
 
 
 @reflection.cache
-def get_columns(self, connection, table_name, schema=None, **kw):
+def get_columns(
+    self, connection, table_name, schema=None, **kw
+):  # pylint: disable=too-many-locals,unused-argument
+    """
+    Method to handle column details
+    """
     if schema is not None:
-        schema_condition = "lower(table_schema) = '%(schema)s'" % {
-            "schema": schema.lower()
-        }
+        schema_condition = f"lower(table_schema) = '{schema.lower()}'"
     else:
         schema_condition = "1"
 
-    s = sql.text(
+    sql_query = sql.text(
         dedent(
             VERTICA_GET_COLUMNS.format(
                 table=table_name.lower(), schema_condition=schema_condition
@@ -70,7 +89,7 @@ def get_columns(self, connection, table_name, schema=None, **kw):
 
     pk_columns = [x[0] for x in connection.execute(spk)]
     columns = []
-    for row in connection.execute(s):
+    for row in connection.execute(sql_query):
         name = row.column_name
         dtype = row.data_type.lower()
         primary_key = name in pk_columns
@@ -78,7 +97,7 @@ def get_columns(self, connection, table_name, schema=None, **kw):
         nullable = row.is_nullable
         comment = row.comment
 
-        column_info = self._get_column_info(
+        column_info = self._get_column_info(  # pylint: disable=protected-access
             name,
             dtype,
             default,
@@ -91,7 +110,7 @@ def get_columns(self, connection, table_name, schema=None, **kw):
     return columns
 
 
-def _get_column_info(
+def _get_column_info(  # pylint: disable=too-many-locals,too-many-branches,too-many-statements
     self,
     name,
     format_type,
@@ -155,14 +174,17 @@ def _get_column_info(
     if coltype:
         coltype = coltype(*args, **kwargs)
     else:
-        util.warn("Did not recognize type '%s' of column '%s'" % (attype, name))
+        util.warn(f"Did not recognize type '{attype}' of column '{name}'")
         coltype = sqltypes.NULLTYPE
     # adjust the default value
     autoincrement = False
     if default is not None:
         match = re.search(r"""(nextval\(')([^']+)('.*$)""", default)
         if match is not None:
-            if issubclass(coltype._type_affinity, sqltypes.Integer):
+            if issubclass(
+                coltype._type_affinity,  # pylint: disable=protected-access
+                sqltypes.Integer,
+            ):
                 autoincrement = True
             # the default is related to a Sequence
             sch = schema
@@ -172,7 +194,7 @@ def _get_column_info(
                 # "quote schema"
                 default = (
                     match.group(1)
-                    + ('"%s"' % sch)
+                    + (f'"{sch}"')
                     + "."
                     + match.group(2)
                     + match.group(3)
@@ -190,37 +212,52 @@ def _get_column_info(
 
 
 @reflection.cache
-def get_view_definition(self, connection, view_name, schema=None, **kw):
+def get_view_definition(
+    self, connection, view_name, schema=None, **kw
+):  # pylint: disable=unused-argument,unused-argument
     if schema is not None:
-        schema_condition = "lower(table_schema) = '%(schema)s'" % {
-            "schema": schema.lower()
-        }
+        schema_condition = f"lower(table_schema) = '{schema.lower()}'"
     else:
         schema_condition = "1"
 
-    s = sql.text(
+    sql_query = sql.text(
         dedent(
             VERTICA_VIEW_DEFINITION.format(
                 view_name=view_name.lower(), schema_condition=schema_condition
             )
         )
     )
-    rows = [row for row in connection.execute(s)]
+    rows = list(connection.execute(sql_query))
     if len(rows) >= 1:
         return rows[0][0]
     return None
 
 
-VerticaDialect.get_columns = get_columns  # pylint: disable=protected-access
+@reflection.cache
+def get_table_comment(
+    self, connection, table_name, schema=None, **kw  # pylint: disable=unused-argument
+):
+    return get_table_comment_wrapper(
+        self,
+        connection,
+        table_name=table_name,
+        schema=schema,
+        query=VERTICA_TABLE_COMMENTS,
+    )
+
+
+VerticaDialect.get_columns = get_columns
 VerticaDialect._get_column_info = _get_column_info  # pylint: disable=protected-access
-VerticaDialect.get_view_definition = (
-    get_view_definition  # pylint: disable=protected-access
-)
+VerticaDialect.get_view_definition = get_view_definition
+VerticaDialect.get_all_table_comments = get_all_table_comments
+VerticaDialect.get_table_comment = get_table_comment
 
 
 class VerticaSource(CommonDbSourceService):
-    def __init__(self, config, metadata_config):
-        super().__init__(config, metadata_config)
+    """
+    Implements the necessary methods to extract
+    Database metadata from Vertica Source
+    """
 
     @classmethod
     def create(cls, config_dict, metadata_config: OpenMetadataConnection):
@@ -231,3 +268,38 @@ class VerticaSource(CommonDbSourceService):
                 f"Expected VerticaConnection, but got {connection}"
             )
         return cls(config, metadata_config)
+
+    def get_database_names(self) -> Iterable[str]:
+        configured_db = self.config.serviceConnection.__root__.config.database
+        if configured_db:
+            self.set_inspector(database_name=configured_db)
+            yield configured_db
+        else:
+            results = self.connection.execute(VERTICA_LIST_DATABASES)
+            for res in results:
+                row = list(res)
+                new_database = row[0]
+                database_fqn = fqn.build(
+                    self.metadata,
+                    entity_type=Database,
+                    service_name=self.context.database_service.name.__root__,
+                    database_name=new_database,
+                )
+
+                if filter_by_database(
+                    self.source_config.databaseFilterPattern,
+                    database_fqn
+                    if self.source_config.useFqnForFiltering
+                    else new_database,
+                ):
+                    self.status.filter(database_fqn, "Database Filtered Out")
+                    continue
+
+                try:
+                    self.set_inspector(database_name=new_database)
+                    yield new_database
+                except Exception as exc:
+                    logger.debug(traceback.format_exc())
+                    logger.error(
+                        f"Error trying to connect to database {new_database}: {exc}"
+                    )
