@@ -18,7 +18,7 @@ Workflow definition for the ORM Profiler.
 """
 import traceback
 from copy import deepcopy
-from typing import Iterable, List, Optional
+from typing import Iterable, List, Optional, cast
 
 from pydantic import ValidationError
 from sqlalchemy import MetaData
@@ -28,16 +28,21 @@ from metadata.config.workflow import get_sink
 from metadata.generated.schema.entity.data.database import Database
 from metadata.generated.schema.entity.data.table import (
     ColumnProfilerConfig,
-    IntervalType,
+    PartitionProfilerConfig,
     Table,
-    TableProfile,
+)
+from metadata.generated.schema.entity.services.connections.database.datalakeConnection import (
+    DatalakeConnection,
 )
 from metadata.generated.schema.entity.services.connections.metadata.openMetadataConnection import (
     OpenMetadataConnection,
 )
-from metadata.generated.schema.entity.services.databaseService import (
-    DatabaseService,
-    DatabaseServiceType,
+from metadata.generated.schema.entity.services.connections.serviceConnection import (
+    ServiceConnection,
+)
+from metadata.generated.schema.entity.services.databaseService import DatabaseService
+from metadata.generated.schema.entity.services.ingestionPipelines.ingestionPipeline import (
+    PipelineState,
 )
 from metadata.generated.schema.entity.services.serviceType import ServiceType
 from metadata.generated.schema.metadataIngestion.databaseServiceProfilerPipeline import (
@@ -49,13 +54,23 @@ from metadata.generated.schema.metadataIngestion.workflow import (
 from metadata.ingestion.api.parser import parse_workflow_config_gracefully
 from metadata.ingestion.api.processor import ProcessorStatus
 from metadata.ingestion.api.sink import Sink
+from metadata.ingestion.models.custom_types import ServiceWithConnectionType
+from metadata.ingestion.ometa.client_utils import create_ometa_client
 from metadata.ingestion.ometa.ometa_api import OpenMetadata
 from metadata.ingestion.source.database.common_db_source import SQLSourceStatus
-from metadata.interfaces.sqa_interface import SQAInterface
+from metadata.interfaces.datalake.datalake_profiler_interface import (
+    DataLakeProfilerInterface,
+)
+from metadata.interfaces.profiler_protocol import (
+    ProfilerInterfaceArgs,
+    ProfilerProtocol,
+)
+from metadata.interfaces.sqalchemy.sqa_profiler_interface import SQAProfilerInterface
 from metadata.orm_profiler.api.models import (
     ProfilerProcessorConfig,
+    ProfilerResponse,
+    ProfileSampleConfig,
     TableConfig,
-    TablePartitionConfig,
 )
 from metadata.orm_profiler.metrics.registry import Metrics
 from metadata.orm_profiler.profiler.core import Profiler
@@ -65,14 +80,21 @@ from metadata.utils.class_helper import (
     get_service_class_from_service_type,
     get_service_type_from_source_type,
 )
+from metadata.utils.connections import get_connection, test_connection
 from metadata.utils.filters import filter_by_database, filter_by_schema, filter_by_table
 from metadata.utils.logger import profiler_logger
+from metadata.utils.partition import get_partition_details
 from metadata.utils.workflow_output_handler import print_profiler_status
+from metadata.workflow.workflow_status_mixin import WorkflowStatusMixin
 
 logger = profiler_logger()
 
 
-class ProfilerWorkflow:
+class ProfilerInterfaceInstantiationError(Exception):
+    """Raise when interface cannot be instantiated"""
+
+
+class ProfilerWorkflow(WorkflowStatusMixin):
     """
     Configure and run the ORM profiler
     """
@@ -82,6 +104,7 @@ class ProfilerWorkflow:
     metadata: OpenMetadata
 
     def __init__(self, config: OpenMetadataWorkflowConfig):
+        self.profiler_obj = None  # defined in `create_profiler_obj()``
         self.config = config
         self.metadata_config: OpenMetadataConnection = (
             self.config.workflowConfig.openMetadataServerConfig
@@ -89,18 +112,17 @@ class ProfilerWorkflow:
         self.profiler_config = ProfilerProcessorConfig.parse_obj(
             self.config.processor.dict().get("config")
         )
-
         self.metadata = OpenMetadata(self.metadata_config)
-
+        self.test_connection()
         self._retrieve_service_connection_if_needed()
-
+        self.set_ingestion_pipeline_status(state=PipelineState.running)
         # Init and type the source config
-        self.source_config: DatabaseServiceProfilerPipeline = (
-            self.config.source.sourceConfig.config
-        )
+        self.source_config: DatabaseServiceProfilerPipeline = cast(
+            DatabaseServiceProfilerPipeline, self.config.source.sourceConfig.config
+        )  # Used to satisfy type checked
         self.source_status = SQLSourceStatus()
         self.status = ProcessorStatus()
-
+        self._profiler_interface_args = None
         if self.config.sink:
             self.sink = get_sink(
                 sink_type=self.config.sink.type,
@@ -113,8 +135,10 @@ class ProfilerWorkflow:
             raise ValueError(
                 f"Service name `{self.config.source.serviceName}` does not exist. "
                 "Make sure you have run the ingestion for the service specified in the profiler workflow. "
-                "If so, make sure the profiler service name matches the service name specified during ingestion."
+                "If so, make sure the profiler service name matches the service name specified during ingestion "
+                "and that your ingestion token (settings > bots) is still valid."
             )
+        self._table_entity = None
 
     @classmethod
     def create(cls, config_dict: dict) -> "ProfilerWorkflow":
@@ -145,14 +169,14 @@ class ProfilerWorkflow:
                 table_config
                 for table_config in self.profiler_config.tableConfig
                 if table_config.fullyQualifiedName.__root__
-                == entity.fullyQualifiedName.__root__
+                == entity.fullyQualifiedName.__root__  # type: ignore
             ),
             None,
         )
 
     def get_include_columns(self, entity) -> Optional[List[ColumnProfilerConfig]]:
         """get included columns"""
-        entity_config: TableConfig = self.get_config_for_entity(entity)
+        entity_config: Optional[TableConfig] = self.get_config_for_entity(entity)
         if entity_config and entity_config.columnConfig:
             return entity_config.columnConfig.includeColumns
 
@@ -163,7 +187,7 @@ class ProfilerWorkflow:
 
     def get_exclude_columns(self, entity) -> Optional[List[str]]:
         """get included columns"""
-        entity_config: TableConfig = self.get_config_for_entity(entity)
+        entity_config: Optional[TableConfig] = self.get_config_for_entity(entity)
         if entity_config and entity_config.columnConfig:
             return entity_config.columnConfig.excludeColumns
 
@@ -172,31 +196,44 @@ class ProfilerWorkflow:
 
         return None
 
-    def get_profile_sample(self, entity: Table) -> Optional[float]:
+    def get_profile_sample(self, entity: Table) -> Optional[dict]:
         """Get profile sample
 
         Args:
             entity: table entity
         """
-        entity_config: TableConfig = self.get_config_for_entity(entity)
+        entity_config: Optional[TableConfig] = self.get_config_for_entity(entity)
         if entity_config:
-            return entity_config.profileSample
+            return ProfileSampleConfig(
+                profile_sample=entity_config.profileSample,
+                profile_sample_type=entity_config.profileSampleType,
+            )
 
-        if entity.tableProfilerConfig:
-            return entity.tableProfilerConfig.profileSample
+        if (
+            hasattr(entity, "tableProfilerConfig")
+            and hasattr(entity.tableProfilerConfig, "profileSample")
+            and entity.tableProfilerConfig.profileSample
+        ):
+
+            return ProfileSampleConfig(
+                profile_sample=entity.tableProfilerConfig.profileSample,
+                profile_sample_type=entity.tableProfilerConfig.profileSampleType,
+            )
 
         if self.source_config.profileSample:
-            return self.source_config.profileSample
-
+            return ProfileSampleConfig(
+                profile_sample=self.source_config.profileSample,
+                profile_sample_type=self.source_config.profileSampleType,
+            )
         return None
 
-    def get_profile_query(self, entity: Table) -> Optional[float]:
+    def get_profile_query(self, entity: Table) -> Optional[str]:
         """Get profile sample
 
         Args:
             entity: table entity
         """
-        entity_config: TableConfig = self.get_config_for_entity(entity)
+        entity_config: Optional[TableConfig] = self.get_config_for_entity(entity)
         if entity_config:
             return entity_config.profileQuery
 
@@ -205,57 +242,56 @@ class ProfilerWorkflow:
 
         return None
 
-    def get_partition_details(self, entity: Table) -> Optional[TablePartitionConfig]:
+    def get_partition_details(self, entity: Table) -> Optional[PartitionProfilerConfig]:
         """Get partition details
 
         Args:
             entity: table entity
         """
-        entity_config: TableConfig = self.get_config_for_entity(entity)
-        if entity_config:
+        entity_config: Optional[TableConfig] = self.get_config_for_entity(entity)
+
+        if entity_config:  # check if a yaml config was pass with partition definition
             return entity_config.partitionConfig
 
-        if hasattr(entity, "tablePartition") and entity.tablePartition:
-            try:
-                if entity.tablePartition.intervalType == IntervalType.TIME_UNIT:
-                    return TablePartitionConfig(
-                        partitionField=entity.tablePartition.columns[0]
-                    )
-                elif entity.tablePartition.intervalType == IntervalType.INGESTION_TIME:
-                    if entity.tablePartition.interval == "DAY":
-                        return TablePartitionConfig(partitionField="_PARTITIONDATE")
-                    return TablePartitionConfig(partitionField="_PARTITIONTIME")
-            except Exception:
-                raise TypeError(
-                    f"Unsupported partition type {entity.tablePartition.intervalType}. Skipping table"
-                )
+        return get_partition_details(entity)
 
     def create_profiler_interface(
         self,
         service_connection_config,
         table_entity: Table,
-        sqa_metadata_obj: Optional[MetaData] = None,
+        sqa_metadata_obj,
     ):
         """Creates a profiler interface object"""
-        return SQAInterface(
-            service_connection_config,
-            sqa_metadata_obj=sqa_metadata_obj,
-            metadata_config=self.metadata_config,
-            thread_count=self.source_config.threadCount,
-            table_entity=table_entity,
-            profile_sample=self.get_profile_sample(table_entity)
-            if not self.get_profile_query(table_entity)
-            else None,
-            profile_query=self.get_profile_query(table_entity)
-            if not self.get_profile_sample(table_entity)
-            else None,
-            partition_config=self.get_partition_details(table_entity)
-            if not self.get_profile_query(table_entity)
-            else None,
-        )
+        try:
+
+            self._table_entity = table_entity
+            self._profiler_interface_args = ProfilerInterfaceArgs(
+                service_connection_config=service_connection_config,
+                sqa_metadata_obj=sqa_metadata_obj,
+                ometa_client=create_ometa_client(self.metadata_config),
+                thread_count=self.source_config.threadCount,
+                table_entity=self._table_entity,
+                profile_sample_config=self.get_profile_sample(self._table_entity)
+                if not self.get_profile_query(self._table_entity)
+                else None,
+                table_sample_query=self.get_profile_query(self._table_entity)
+                if not self.get_profile_sample(self._table_entity)
+                else None,
+                table_partition_config=self.get_partition_details(self._table_entity)
+                if not self.get_profile_query(self._table_entity)
+                else None,
+                timeout_seconds=self.source_config.timeoutSeconds,
+            )
+            if isinstance(service_connection_config, DatalakeConnection):
+                return DataLakeProfilerInterface(self._profiler_interface_args)
+            return SQAProfilerInterface(self._profiler_interface_args)
+        except Exception as exc:
+            logger.debug(traceback.format_exc())
+            logger.error("We could not create a profiler interface")
+            raise ProfilerInterfaceInstantiationError(exc)
 
     def create_profiler_obj(
-        self, table_entity: Table, profiler_interface: SQAInterface
+        self, table_entity: Table, profiler_interface: ProfilerProtocol
     ):
         """Profile a single entity"""
         if not self.profiler_config.profiler:
@@ -272,7 +308,7 @@ class ProfilerWorkflow:
             )
 
             self.profiler_obj = Profiler(
-                *metrics,
+                *metrics,  # type: ignore
                 profiler_interface=profiler_interface,
                 include_columns=self.get_include_columns(table_entity),
                 exclude_columns=self.get_exclude_columns(table_entity),
@@ -288,10 +324,9 @@ class ProfilerWorkflow:
                 database.name.__root__, "Database pattern not allowed"
             )
             return None
-        else:
-            return database
+        return database
 
-    def filter_entities(self, tables: List[Table]) -> Iterable[Table]:
+    def filter_entities(self, tables: Iterable[Table]) -> Iterable[Table]:
         """
         From a list of tables, apply the SQLSourceConfig
         filter patterns.
@@ -302,10 +337,10 @@ class ProfilerWorkflow:
             try:
                 if filter_by_schema(
                     self.source_config.schemaFilterPattern,
-                    table.databaseSchema.name,
+                    table.databaseSchema.name,  # type: ignore
                 ):
                     self.source_status.filter(
-                        f"Schema pattern not allowed: {table.fullyQualifiedName.__root__}",
+                        f"Schema pattern not allowed: {table.fullyQualifiedName.__root__}",  # type: ignore
                         "Schema pattern not allowed",
                     )
                     continue
@@ -314,7 +349,7 @@ class ProfilerWorkflow:
                     table.name.__root__,
                 ):
                     self.source_status.filter(
-                        f"Table pattern not allowed: {table.fullyQualifiedName.__root__}",
+                        f"Table pattern not allowed: {table.fullyQualifiedName.__root__}",  # type: ignore
                         "Table pattern not allowed",
                     )
                     continue
@@ -323,9 +358,10 @@ class ProfilerWorkflow:
             except Exception as exc:  # pylint: disable=broad-except
                 logger.debug(traceback.format_exc())
                 logger.warning(
-                    f"Unexpected error filtering entities for table [{table.fullyQualifiedName.__root__}]: {exc}"
+                    "Unexpected error filtering entities for table "
+                    f"[{table.fullyQualifiedName.__root__}]: {exc}"  # type: ignore
                 )
-                self.source_status.failure(table.fullyQualifiedName.__root__, f"{exc}")
+                self.source_status.failure(table.fullyQualifiedName.__root__, f"{exc}")  # type: ignore
 
     def get_database_entities(self):
         """List all databases in service"""
@@ -358,7 +394,6 @@ class ProfilerWorkflow:
             entity=Table,
             fields=[
                 "tableProfilerConfig",
-                "tests",
             ],
             params={
                 "service": self.config.source.serviceName,
@@ -368,52 +403,57 @@ class ProfilerWorkflow:
                     service_name=self.config.source.serviceName,
                     database_name=database.name.__root__,
                 ),
-            },
+            },  # type: ignore
         )
 
         yield from self.filter_entities(all_tables)
 
-    def copy_service_config(self, database) -> None:
+    def copy_service_config(self, database) -> DatabaseService.__config__:
         copy_service_connection_config = deepcopy(
-            self.config.source.serviceConnection.__root__.config
+            self.config.source.serviceConnection.__root__.config  # type: ignore
         )
         if hasattr(
-            self.config.source.serviceConnection.__root__.config,
+            self.config.source.serviceConnection.__root__.config,  # type: ignore
             "supportsDatabase",
         ):
-            if hasattr(
-                self.config.source.serviceConnection.__root__.config, "database"
-            ):
-                copy_service_connection_config.database = database.name.__root__
-            if hasattr(self.config.source.serviceConnection.__root__.config, "catalog"):
-                copy_service_connection_config.catalog = database.name.__root__
+            if hasattr(copy_service_connection_config, "database"):
+                copy_service_connection_config.database = database.name.__root__  # type: ignore
+            if hasattr(copy_service_connection_config, "catalog"):
+                copy_service_connection_config.catalog = database.name.__root__  # type: ignore
+
+        # we know we'll only be working with databaseServices, we cast the type to satisfy type checker
+        copy_service_connection_config = cast(
+            DatabaseService.__config__, copy_service_connection_config
+        )
 
         return copy_service_connection_config
 
-    def execute(self):
+    def run_profiler_workflow(self):
         """
-        Run the profiling and tests
+        Main logic for the profiler workflow
         """
-
         databases = self.get_database_entities()
 
         if not databases:
             raise ValueError(
                 "databaseFilterPattern returned 0 result. At least 1 database must be returned by the filter pattern."
-                f"\n\t- includes: {self.source_config.databaseFilterPattern.includes}\n\t- excludes: {self.source_config.databaseFilterPattern.excludes}"
+                f"\n\t- includes: {self.source_config.databaseFilterPattern.includes if self.source_config.databaseFilterPattern else None}"  # pylint: disable=line-too-long
+                f"\n\t- excludes: {self.source_config.databaseFilterPattern.excludes if self.source_config.databaseFilterPattern else None}"  # pylint: disable=line-too-long
             )
 
         for database in databases:
             copied_service_config = self.copy_service_config(database)
-            sqa_metadata_obj = MetaData()
             try:
+                sqa_metadata_obj = MetaData()
                 for entity in self.get_table_entities(database=database):
                     try:
                         profiler_interface = self.create_profiler_interface(
-                            copied_service_config, entity, sqa_metadata_obj
+                            sqa_metadata_obj=sqa_metadata_obj,
+                            service_connection_config=copied_service_config,
+                            table_entity=entity,
                         )
                         self.create_profiler_obj(entity, profiler_interface)
-                        profile: TableProfile = self.profiler_obj.process(
+                        profile: ProfilerResponse = self.profiler_obj.process(
                             self.source_config.generateSampleData
                         )
                         profiler_interface.close()
@@ -422,18 +462,20 @@ class ProfilerWorkflow:
                         self.status.failures.extend(
                             profiler_interface.processor_status.failures
                         )  # we can have column level failures we need to report
-                        self.status.processed(entity.fullyQualifiedName.__root__)
-                        self.source_status.scanned(entity.fullyQualifiedName.__root__)
+                        self.status.processed(entity.fullyQualifiedName.__root__)  # type: ignore
+                        self.source_status.scanned(entity.fullyQualifiedName.__root__)  # type: ignore
                     except Exception as exc:  # pylint: disable=broad-except
+
                         logger.debug(traceback.format_exc())
                         logger.warning(
-                            f"Unexpected exception processing entity [{entity.fullyQualifiedName.__root__}]: {exc}"
+                            "Unexpected exception processing entity "
+                            f"[{entity.fullyQualifiedName.__root__}]: {exc}"  # type: ignore
                         )
                         self.status.failures.extend(
-                            profiler_interface.processor_status.failures
+                            profiler_interface.processor_status.failures  # type: ignore
                         )
                         self.source_status.failure(
-                            entity.fullyQualifiedName.__root__, f"{exc}"
+                            entity.fullyQualifiedName.__root__, f"{exc}"  # type: ignore
                         )
             except Exception as exc:  # pylint: disable=broad-except
                 logger.debug(traceback.format_exc())
@@ -441,6 +483,21 @@ class ProfilerWorkflow:
                     f"Unexpected exception executing in database [{database}]: {exc}"
                 )
 
+    def execute(self):
+        """
+        Run the profiling and tests
+        """
+
+        try:
+            self.run_profiler_workflow()
+            # At the end of the `execute`, update the associated Ingestion Pipeline status as success
+            self.set_ingestion_pipeline_status(PipelineState.success)
+
+        # Any unhandled exception breaking the workflow should update the status
+        except Exception as err:
+            self.set_ingestion_pipeline_status(PipelineState.failed)
+            raise err
+
     def print_status(self) -> None:
         """
         Print the workflow results with click
@@ -457,10 +514,9 @@ class ProfilerWorkflow:
             or (hasattr(self, "sink") and self.sink.get_status().failures)
         ):
             return 1
-        else:
-            return 0
+        return 0
 
-    def raise_from_status(self, raise_warnings=False):
+    def _raise_from_status_internal(self, raise_warnings=False):
         """
         Check source, processor and sink status and raise if needed
 
@@ -505,21 +561,31 @@ class ProfilerWorkflow:
 
         :return:
         """
-        if not self._is_sample_source(self.config.source.type):
-            service_type: ServiceType = get_service_type_from_source_type(
-                self.config.source.type
-            )
-            service = self.metadata.get_by_name(
-                get_service_class_from_service_type(service_type),
-                self.config.source.serviceName,
-            )
-            if service:
-                self.config.source.serviceConnection = (
-                    self.metadata.secrets_manager_client.retrieve_service_connection(
-                        service, service_type.name.lower()
+        service_type: ServiceType = get_service_type_from_source_type(
+            self.config.source.type
+        )
+        if self.config.source.serviceConnection:
+            service_name = self.config.source.serviceName
+            try:
+                service: ServiceWithConnectionType = cast(
+                    ServiceWithConnectionType,
+                    self.metadata.get_by_name(
+                        get_service_class_from_service_type(service_type),
+                        service_name,
+                    ),
+                )
+                if service:
+                    self.config.source.serviceConnection = ServiceConnection(
+                        __root__=service.connection
                     )
+            except Exception as exc:
+                logger.debug(traceback.format_exc())
+                logger.error(
+                    f"Error getting service connection for service name [{service_name}]"
+                    f" using the secrets manager provider [{self.metadata.config.secretsManagerProvider}]: {exc}"
                 )
 
-    @staticmethod
-    def _is_sample_source(service_type):
-        return service_type == "sample-data" or service_type == "sample-usage"
+    def test_connection(self):
+        service_config = self.config.source.serviceConnection.__root__.config
+        self.engine = get_connection(service_config)
+        test_connection(self.engine)
