@@ -29,7 +29,7 @@ class MedianFn(FunctionElement):
 
 
 @compiles(MedianFn)
-def _(elements, compiler, **kwargs):
+def _(elements, compiler, **kwargs):  # pylint: disable=unused-argument
     col = elements.clauses.clauses[0].name
     return "percentile_cont(0.5) WITHIN GROUP (ORDER BY %s ASC)" % col
 
@@ -40,24 +40,25 @@ def _(elements, compiler, **kwargs):
     return "percentile_cont(%s , 0.5) OVER()" % col
 
 
-@compiles(MedianFn, Dialects.Athena)
 @compiles(MedianFn, Dialects.ClickHouse)
 def _(elements, compiler, **kwargs):
     col, _ = [compiler.process(element, **kwargs) for element in elements.clauses]
     return "median(%s)" % col
 
 
+# pylint: disable=unused-argument
+@compiles(MedianFn, Dialects.Athena)
 @compiles(MedianFn, Dialects.Trino)
 @compiles(MedianFn, Dialects.Presto)
 def _(elements, compiler, **kwargs):
     col = elements.clauses.clauses[0].name
-    return "approx_percentile(%s, 0.5)" % col
+    return 'approx_percentile("%s", 0.5)' % col
 
 
 @compiles(MedianFn, Dialects.MSSQL)
 def _(elements, compiler, **kwargs):
     """Median computation for MSSQL"""
-    col, _ = [compiler.process(element, **kwargs) for element in elements.clauses]
+    col = elements.clauses.clauses[0].name
     return "percentile_cont(0.5)  WITHIN GROUP (ORDER BY %s ASC) OVER()" % col
 
 
@@ -69,7 +70,7 @@ def _(elements, compiler, **kwargs):
 
 
 @compiles(MedianFn, Dialects.MySQL)
-def _(elemenst, compiler, **kwargs):
+def _(elemenst, compiler, **kwargs):  # pylint: disable=unused-argument
     """Median computation for MySQL currently not supported
     Needs to be tackled in https://github.com/open-metadata/OpenMetadata/issues/6340
     """
@@ -77,8 +78,8 @@ def _(elemenst, compiler, **kwargs):
 
 
 @compiles(MedianFn, Dialects.SQLite)
-def _(elements, compiler, **kwargs):
-    col, table = [element for element in elements.clauses]
+def _(elements, compiler, **kwargs):  # pylint: disable=unused-argument
+    col, table = list(elements.clauses)
     return """
     (SELECT 
         AVG({col})
@@ -92,3 +93,11 @@ def _(elements, compiler, **kwargs):
     """.format(
         col=col, table=table.value
     )
+
+
+@compiles(MedianFn, Dialects.Vertica)
+def _(elements, compiler, **kwargs):  # pylint: disable=unused-argument
+    col, table = list(elements.clauses)
+    return "(SELECT MEDIAN({col}) OVER() FROM {table} LIMIT 1)".format(
+        col=col, table=table.value
+    )
