@@ -13,7 +13,7 @@
 Define Modulo function
 """
 # Keep SQA docs style defining custom constructs
-# pylint: disable=consider-using-f-string,duplicate-code
+# pylint: disable=duplicate-code
 
 from sqlalchemy.ext.compiler import compiles
 from sqlalchemy.sql.functions import FunctionElement
@@ -56,6 +56,7 @@ def _(element, compiler, **kw):
 @compiles(ModuloFn, Dialects.Oracle)
 @compiles(ModuloFn, Dialects.Presto)
 @compiles(ModuloFn, Dialects.Trino)
+@compiles(ModuloFn, Dialects.Vertica)
 def _(element, compiler, **kw):
     """Modulo function for specific dialect"""
     value, base = validate_and_compile(element, compiler, **kw)
@@ -74,3 +75,13 @@ def _(element, compiler, **kw):
     """SQLite modulo function"""
     value, base = validate_and_compile(element, compiler, **kw)
     return f"{value} % {base}"
+
+
+@compiles(ModuloFn, Dialects.MSSQL)
+def _(element, compiler, **kw):
+    """Azure SQL modulo function"""
+    value, base = validate_and_compile(element, compiler, **kw)
+    if compiler.dialect.driver == "pyodbc":
+        # pyodbc compiles to c++ code.
+        return f"{value} % {base}"
+    return f"{value} %% {base}"
