@@ -22,18 +22,22 @@ from logging import Logger
 from typing import List, Optional, Set, Tuple
 
 from pydantic import ValidationError
+from sqlalchemy import MetaData
 
 from metadata.config.common import WorkflowExecutionError
 from metadata.config.workflow import get_sink
 from metadata.generated.schema.api.tests.createTestCase import CreateTestCaseRequest
 from metadata.generated.schema.api.tests.createTestSuite import CreateTestSuiteRequest
-from metadata.generated.schema.entity.data.table import IntervalType, Table
+from metadata.generated.schema.entity.data.table import PartitionProfilerConfig, Table
+from metadata.generated.schema.entity.services.connections.database.datalakeConnection import (
+    DatalakeConnection,
+)
 from metadata.generated.schema.entity.services.connections.metadata.openMetadataConnection import (
     OpenMetadataConnection,
 )
-from metadata.generated.schema.entity.services.databaseService import (
-    DatabaseService,
-    DatabaseServiceType,
+from metadata.generated.schema.entity.services.databaseService import DatabaseService
+from metadata.generated.schema.entity.services.ingestionPipelines.ingestionPipeline import (
+    PipelineState,
 )
 from metadata.generated.schema.metadataIngestion.testSuitePipeline import (
     TestSuitePipeline,
@@ -46,19 +50,26 @@ from metadata.generated.schema.tests.testDefinition import TestDefinition
 from metadata.generated.schema.tests.testSuite import TestSuite
 from metadata.ingestion.api.parser import parse_workflow_config_gracefully
 from metadata.ingestion.api.processor import ProcessorStatus
+from metadata.ingestion.ometa.client_utils import create_ometa_client
 from metadata.ingestion.ometa.ometa_api import OpenMetadata
-from metadata.interfaces.sqa_interface import SQAInterface
-from metadata.orm_profiler.api.models import TablePartitionConfig
+from metadata.ingestion.source.database.datalake import ometa_to_dataframe
+from metadata.interfaces.datalake.datalake_test_suite_interface import (
+    DataLakeTestSuiteInterface,
+)
+from metadata.interfaces.sqalchemy.sqa_test_suite_interface import SQATestSuiteInterface
 from metadata.test_suite.api.models import TestCaseDefinition, TestSuiteProcessorConfig
 from metadata.test_suite.runner.core import DataTestsRunner
 from metadata.utils import entity_link
+from metadata.utils.connections import get_connection
 from metadata.utils.logger import test_suite_logger
+from metadata.utils.partition import get_partition_details
 from metadata.utils.workflow_output_handler import print_test_suite_status
+from metadata.workflow.workflow_status_mixin import WorkflowStatusMixin
 
 logger: Logger = test_suite_logger()
 
 
-class TestSuiteWorkflow:
+class TestSuiteWorkflow(WorkflowStatusMixin):
     """workflow to run the test suite"""
 
     def __init__(self, config: OpenMetadataWorkflowConfig):
@@ -84,8 +95,11 @@ class TestSuiteWorkflow:
         self.metadata_config: OpenMetadataConnection = (
             self.config.workflowConfig.openMetadataServerConfig
         )
+        self.client = create_ometa_client(self.metadata_config)
         self.metadata = OpenMetadata(self.metadata_config)
 
+        self.set_ingestion_pipeline_status(state=PipelineState.running)
+
         self.status = ProcessorStatus()
 
         if self.config.sink:
@@ -115,71 +129,62 @@ class TestSuiteWorkflow:
             )
             raise err
 
-    def _filter_test_cases_for_table_entity(
-        self, table_fqn: str, test_cases: List[TestCase]
+    def _filter_test_cases_for_entity(
+        self, entity_fqn: str, test_cases: List[TestCase]
     ) -> list[TestCase]:
         """Filter test cases for specific entity"""
         return [
             test_case
             for test_case in test_cases
             if test_case.entityLink.__root__.split("::")[2].replace(">", "")
-            == table_fqn
+            == entity_fqn
         ]
 
-    def _get_unique_table_entities(self, test_cases: List[TestCase]) -> Set:
+    def _get_unique_entities_from_test_cases(self, test_cases: List[TestCase]) -> Set:
         """from a list of test cases extract unique table entities"""
-        table_fqns = [
+        entity_fqns = [
             test_case.entityLink.__root__.split("::")[2].replace(">", "")
             for test_case in test_cases
         ]
 
-        return set(table_fqns)
+        return set(entity_fqns)
 
-    def _get_service_connection_from_test_case(self, table_fqn: str):
+    def _get_service_connection_from_test_case(self, entity_fqn: str):
         """given an entityLink return the service connection
 
         Args:
-            entity_link: entity link for the test case
+            entity_fqn: entity link for the test case
         """
-        if self.config.source.type not in {"sample-data", "sample-usage"}:
-            service = self.metadata.get_by_name(
-                entity=DatabaseService,
-                fqn=table_fqn.split(".")[0],
-            )
+        service: DatabaseService = self.metadata.get_by_name(
+            entity=DatabaseService,
+            fqn=entity_fqn.split(".")[0],
+        )
 
-            if service:
-                service_connection = (
-                    self.metadata.secrets_manager_client.retrieve_service_connection(
-                        service,
-                        "databaseservice",
+        if service:
+            service_connection_config = deepcopy(service.connection.config)
+            if hasattr(service_connection_config, "supportsDatabase"):
+                if (
+                    hasattr(
+                        service_connection_config,
+                        "database",
                     )
-                )
-                service_connection_config = deepcopy(service_connection.__root__.config)
-                if hasattr(service_connection_config, "supportsDatabase"):
-                    if (
-                        hasattr(
-                            service_connection_config,
-                            "database",
-                        )
-                        and not service_connection_config.database
-                    ):
-                        service_connection_config.database = table_fqn.split(".")[1]
-                    if (
-                        hasattr(
-                            service_connection_config,
-                            "catalog",
-                        )
-                        and not service_connection_config.catalog
-                    ):
-                        service_connection_config.catalog = table_fqn.split(".")[1]
-                return service_connection_config
+                    and not service_connection_config.database
+                ):
+                    service_connection_config.database = entity_fqn.split(".")[1]
+                if (
+                    hasattr(
+                        service_connection_config,
+                        "catalog",
+                    )
+                    and not service_connection_config.catalog
+                ):
+                    service_connection_config.catalog = entity_fqn.split(".")[1]
+            return service_connection_config
 
-            logger.error(
-                f"Could not retrive connection details for entity {entity_link}"
-            )
-            raise ValueError()
+        logger.error(f"Could not retrive connection details for entity {entity_link}")
+        raise ValueError()
 
-    def _get_table_entity_from_test_case(self, table_fqn: str):
+    def _get_table_entity_from_test_case(self, entity_fqn: str):
         """given an entityLink return the table entity
 
         Args:
@@ -187,7 +192,7 @@ class TestSuiteWorkflow:
         """
         return self.metadata.get_by_name(
             entity=Table,
-            fqn=table_fqn,
+            fqn=entity_fqn,
             fields=["profile"],
         )
 
@@ -212,55 +217,53 @@ class TestSuiteWorkflow:
 
         return None
 
-    def _get_partition_details(self, entity: Table) -> Optional[TablePartitionConfig]:
+    def _get_partition_details(
+        self, entity: Table
+    ) -> Optional[PartitionProfilerConfig]:
         """Get partition details
 
         Args:
             entity: table entity
         """
-        # Should remove this with https://github.com/open-metadata/OpenMetadata/issues/5458
-        if entity.serviceType != DatabaseServiceType.BigQuery:
-            return None
-        if entity.tablePartition:
-            if entity.tablePartition.intervalType in {
-                IntervalType.TIME_UNIT,
-                IntervalType.INGESTION_TIME,
-            }:
-                try:
-                    partition_field = entity.tablePartition.columns[0]
-                except Exception:
-                    raise TypeError(
-                        "Unsupported ingestion based partition type. Skipping table"
-                    )
+        return get_partition_details(entity)
 
-                return TablePartitionConfig(
-                    partitionField=partition_field,
-                )
-
-            raise TypeError(
-                f"Unsupported partition type {entity.tablePartition.intervalType}. Skipping table"
-            )
-
-        return None
-
-    def _create_sqa_tests_runner_interface(self, table_fqn: str):
-        """create the interface to execute test against SQA sources"""
-        table_entity = self._get_table_entity_from_test_case(table_fqn)
-        return SQAInterface(
-            service_connection_config=self._get_service_connection_from_test_case(
-                table_fqn
-            ),
-            metadata_config=self.metadata_config,
-            table_entity=table_entity,
-            profile_sample=self._get_profile_sample(table_entity)
-            if not self._get_profile_query(table_entity)
-            else None,
-            profile_query=self._get_profile_query(table_entity)
+    def _create_runner_interface(self, entity_fqn: str):
+        """create the interface to execute test against sources"""
+        table_entity = self._get_table_entity_from_test_case(entity_fqn)
+        service_connection_config = self._get_service_connection_from_test_case(
+            entity_fqn
+        )
+        table_partition_config = None
+        profile_sample_config = None
+        table_sample_query = (
+            self._get_profile_query(table_entity)
             if not self._get_profile_sample(table_entity)
-            else None,
-            partition_config=self._get_partition_details(table_entity)
-            if not self._get_profile_query(table_entity)
-            else None,
+            else None
+        )
+        if not table_sample_query:
+            profile_sample_config = self._get_profile_sample(table_entity)
+            table_partition_config = self._get_partition_details(table_entity)
+
+        if not isinstance(service_connection_config, DatalakeConnection):
+            sqa_metadata_obj = MetaData()
+            return SQATestSuiteInterface(
+                service_connection_config=service_connection_config,
+                ometa_client=self.client,
+                sqa_metadata_obj=sqa_metadata_obj,
+                table_entity=table_entity,
+                profile_sample_config=profile_sample_config,
+                table_sample_query=table_sample_query,
+                table_partition_config=table_partition_config,
+            )
+        return DataLakeTestSuiteInterface(
+            service_connection_config=service_connection_config,
+            ometa_client=self.client,
+            data_frame=ometa_to_dataframe(
+                service_connection_config.configSource,
+                get_connection(service_connection_config).client,
+                table_entity,
+            )[0],
+            table_entity=table_entity,
         )
 
     def _create_data_tests_runner(self, sqa_interface):
@@ -350,9 +353,9 @@ class TestSuiteWorkflow:
             cli_config_test_case_name: test cases defined in CLI workflow associated with its test suite
             test_cases: list of test cases entities fetch from the server using test suite names in the config file
         """
-        test_case_names_to_create = set(
-            [test_case_def[0].name for test_case_def in cli_config_test_cases_def]
-        ) - set([test_case.name.__root__ for test_case in test_cases])
+        test_case_names_to_create = {
+            test_case_def[0].name for test_case_def in cli_config_test_cases_def
+        } - {test_case.name.__root__ for test_case in test_cases}
 
         if not test_case_names_to_create:
             return None
@@ -381,10 +384,9 @@ class TestSuiteWorkflow:
                             testSuite=self.metadata.get_entity_reference(
                                 entity=TestSuite, fqn=test_suite.name
                             ),
-                            parameterValues=[
-                                parameter_values
-                                for parameter_values in test_case_to_create.parameterValues
-                            ],
+                            parameterValues=list(test_case_to_create.parameterValues)
+                            if test_case_to_create.parameterValues
+                            else None,
                         )
                     )
                 )
@@ -393,11 +395,25 @@ class TestSuiteWorkflow:
                     f"Couldn't create test case name {test_case_name_to_create}: {exc}"
                 )
                 logger.debug(traceback.format_exc())
+                self.status.failure(
+                    test_case_to_create.entityLink.__root__.split("::")[2]
+                )
 
         return created_test_case
 
-    def execute(self):
-        """Execute test suite workflow"""
+    def add_test_cases_from_cli_config(self, test_cases: list) -> list:
+        cli_config_test_cases_def = self.get_test_case_from_cli_config()
+        runtime_created_test_cases = self.compare_and_create_test_cases(
+            cli_config_test_cases_def, test_cases
+        )
+        if runtime_created_test_cases:
+            return runtime_created_test_cases
+        return []
+
+    def run_test_suite(self):
+        """
+        Main running logic
+        """
         test_suites = (
             self.get_test_suite_entity_for_ui_workflow()
             or self.get_or_create_test_suite_entity_for_cli_workflow()
@@ -408,30 +424,26 @@ class TestSuiteWorkflow:
 
         test_cases = self.get_test_cases_from_test_suite(test_suites)
         if self.processor_config.testSuites:
-            cli_config_test_cases_def = self.get_test_case_from_cli_config()
-            runtime_created_test_cases = self.compare_and_create_test_cases(
-                cli_config_test_cases_def, test_cases
-            )
-            if runtime_created_test_cases:
-                test_cases.extend(runtime_created_test_cases)
+            test_cases.extend(self.add_test_cases_from_cli_config(test_cases))
 
-        unique_table_fqns = self._get_unique_table_entities(test_cases)
+        unique_entity_fqns = self._get_unique_entities_from_test_cases(test_cases)
 
-        for table_fqn in unique_table_fqns:
+        for entity_fqn in unique_entity_fqns:
             try:
-                sqa_interface = self._create_sqa_tests_runner_interface(table_fqn)
-                for test_case in self._filter_test_cases_for_table_entity(
-                    table_fqn, test_cases
+                runner_interface = self._create_runner_interface(entity_fqn)
+                data_test_runner = self._create_data_tests_runner(runner_interface)
+
+                for test_case in self._filter_test_cases_for_entity(
+                    entity_fqn, test_cases
                 ):
                     try:
-                        data_test_runner = self._create_data_tests_runner(sqa_interface)
                         test_result = data_test_runner.run_and_handle(test_case)
                         if not test_result:
                             continue
                         if hasattr(self, "sink"):
                             self.sink.write_record(test_result)
                         logger.info(
-                            f"Successfuly ran test case {test_case.name.__root__}"
+                            f"Successfully ran test case {test_case.name.__root__}"
                         )
                         self.status.processed(test_case.fullyQualifiedName.__root__)
                     except Exception as exc:
@@ -439,10 +451,23 @@ class TestSuiteWorkflow:
                         logger.warning(
                             f"Could not run test case {test_case.name}: {exc}"
                         )
+                        self.status.failure(entity_fqn)
             except TypeError as exc:
                 logger.debug(traceback.format_exc())
-                logger.warning(f"Could not run test case {test_case.name}: {exc}")
-                self.status.failure(test_case.fullyQualifiedName.__root__)
+                logger.warning(f"Could not run test case for table {entity_fqn}: {exc}")
+                self.status.failure(entity_fqn)
+
+    def execute(self):
+        """Execute test suite workflow"""
+        try:
+            self.run_test_suite()
+            # At the end of the `execute`, update the associated Ingestion Pipeline status as success
+            self.set_ingestion_pipeline_status(PipelineState.success)
+
+        # Any unhandled exception breaking the workflow should update the status
+        except Exception as err:
+            self.set_ingestion_pipeline_status(PipelineState.failed)
+            raise err
 
     def print_status(self) -> None:
         """
@@ -460,7 +485,7 @@ class TestSuiteWorkflow:
             return 1
         return 0
 
-    def raise_from_status(self, raise_warnings=False):
+    def _raise_from_status_internal(self, raise_warnings=False):
         """
         Check source, processor and sink status and raise if needed
 
