@@ -55,14 +55,14 @@ class FQNBuildingException(Exception):
     """
 
 
-def split(s: str) -> List[str]:
+def split(s: str) -> List[str]:  # pylint: disable=invalid-name
     """
     Equivalent of Java's FullyQualifiedName#split
     """
     lexer = FqnLexer(InputStream(s))
     stream = CommonTokenStream(lexer)
     parser = FqnParser(stream)
-    parser._errHandler = BailErrorStrategy()
+    parser._errHandler = BailErrorStrategy()  # pylint: disable=protected-access
     tree = parser.fqn()
     walker = ParseTreeWalker()
     splitter = FqnSplitListener()
@@ -115,12 +115,12 @@ def build(metadata: OpenMetadata, entity_type: Type[T], **kwargs) -> Optional[st
     :param kwargs: required to build the FQN
     :return: FQN as a string
     """
-    fn = fqn_build_registry.registry.get(entity_type.__name__)
-    if not fn:
+    func = fqn_build_registry.registry.get(entity_type.__name__)
+    if not func:
         raise FQNBuildingException(
             f"Invalid Entity Type {entity_type.__name__}. FQN builder not implemented."
         )
-    return fn(metadata, **kwargs)
+    return func(metadata, **kwargs)
 
 
 @fqn_build_registry.add(Table)
@@ -132,6 +132,7 @@ def _(
     schema_name: Optional[str],
     table_name: str,
     fetch_multiple_entities: bool = False,
+    skip_es_search: bool = False,
 ) -> Union[Optional[str], Optional[List[str]]]:
     """
     Building logic for tables
@@ -142,31 +143,31 @@ def _(
     :param table_name: Table name
     :return:
     """
-    if not service_name or not table_name:
-        raise FQNBuildingException(
-            f"Service Name and Table Name should be informed, but got service=`{service_name}`, table=`{table_name}`"
-        )
+    fqn_search_string = build_es_fqn_search_string(
+        database_name, schema_name, service_name, table_name
+    )
 
-    if not database_name or not schema_name:
-
-        fqn_search_string = _build(
-            service_name, database_name or "*", schema_name or "*", table_name
-        )
-
-        es_result = metadata.es_search_from_fqn(
+    es_result = (
+        metadata.es_search_from_fqn(
             entity_type=Table,
             fqn_search_string=fqn_search_string,
         )
-        entity: Optional[Union[Table, List[Table]]] = get_entity_from_es_result(
-            entity_list=es_result, fetch_multiple_entities=fetch_multiple_entities
-        )
-        if not entity:
-            return None
-        if fetch_multiple_entities:
-            return [str(table.fullyQualifiedName.__root__) for table in entity]
+        if not skip_es_search
+        else None
+    )
+
+    entity: Optional[Union[Table, List[Table]]] = get_entity_from_es_result(
+        entity_list=es_result, fetch_multiple_entities=fetch_multiple_entities
+    )
+    # if entity not found in ES proceed to build FQN with database_name and schema_name
+    if not entity and database_name and schema_name:
+        fqn = _build(service_name, database_name, schema_name, table_name)
+        return [fqn] if fetch_multiple_entities else fqn
+    if entity and fetch_multiple_entities:
+        return [str(table.fullyQualifiedName.__root__) for table in entity]
+    if entity:
         return str(entity.fullyQualifiedName.__root__)
-    fqn = _build(service_name, database_name, schema_name, table_name)
-    return [fqn] if fetch_multiple_entities else fqn
+    return None
 
 
 @fqn_build_registry.add(DatabaseSchema)
@@ -394,14 +395,13 @@ def _(
             column_name,
             test_case_name,
         )
-    else:
-        return _build(
-            service_name,
-            database_name,
-            schema_name,
-            table_name,
-            test_case_name,
-        )
+    return _build(
+        service_name,
+        database_name,
+        schema_name,
+        table_name,
+        test_case_name,
+    )
 
 
 def split_table_name(table_name: str) -> Dict[str, Optional[str]]:
@@ -411,8 +411,9 @@ def split_table_name(table_name: str) -> Dict[str, Optional[str]]:
     :param table_name: raw table name
     :return: dict with data
     """
-
-    details: List[str] = split(table_name)
+    # Revisit: Check the antlr grammer for issue when string has double quotes
+    # Issue Link: https://github.com/open-metadata/OpenMetadata/issues/8874
+    details: List[str] = split(table_name.replace('"', ""))
     # Pad None to the left until size of list is 3
     full_details: List[Optional[str]] = ([None] * (3 - len(details))) + details
 
@@ -440,6 +441,38 @@ def split_test_case_fqn(test_case_fqn: str) -> Dict[str, Optional[str]]:
     if len(details) != 6:
         details.insert(4, None)
 
-    service, database, schema, table, column, test_case = details
+    (  # pylint: disable=unbalanced-tuple-unpacking
+        service,
+        database,
+        schema,
+        table,
+        column,
+        test_case,
+    ) = details
 
     return SplitTestCaseFqn(service, database, schema, table, column, test_case)
+
+
+def build_es_fqn_search_string(
+    database_name: str, schema_name, service_name, table_name
+) -> str:
+    """
+    Builds FQN search string for ElasticSearch
+
+    Args:
+        service_name: service name to filter
+        database_name: DB name or None
+        schema_name: schema name or None
+        table_name: table name
+
+    Returns:
+        FQN search string
+    """
+    if not service_name or not table_name:
+        raise FQNBuildingException(
+            f"Service Name and Table Name should be informed, but got service=`{service_name}`, table=`{table_name}`"
+        )
+    fqn_search_string = _build(
+        service_name, database_name or "*", schema_name or "*", table_name
+    )
+    return fqn_search_string
